@@ -5,10 +5,6 @@
 
 RDF::Query::Algebra::Distinct - Algebra class for distinct query results
 
-=head1 VERSION
-
-This document describes RDF::Query::Algebra::Distinct version 2.917_01.
-
 =cut
 
 package RDF::Query::Algebra::Distinct;
@@ -21,23 +17,22 @@ use base qw(RDF::Query::Algebra);
 use Data::Dumper;
 use Set::Scalar;
 use Scalar::Util qw(blessed);
+use List::MoreUtils qw(uniq);
 use Carp qw(carp croak confess);
 use RDF::Trine::Iterator qw(sgrep);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -75,33 +70,28 @@ Returns the pattern to be sorted.
 
 sub pattern {
 	my $self	= shift;
-	if (@_) {
-		$self->[0]	= shift;
-	}
 	return $self->[0];
 }
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
 sub sse {
 	my $self	= shift;
 	my $context	= shift;
-	my $prefix	= shift || '';
-	my $indent	= $context->{indent} || '  ';
 	
 	return sprintf(
-		"(distinct\n${prefix}${indent}%s)",
-		$self->pattern->sse( $context, "${prefix}${indent}" ),
+		'(distinct %s)',
+		$self->pattern->sse( $context ),
 	);
 }
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -110,41 +100,10 @@ sub as_sparql {
 	my $context	= shift;
 	my $indent	= shift;
 	
-	return 'DISTINCT ' . $self->pattern->as_sparql( $context, $indent );
-}
-
-=item C<< as_hash >>
-
-Returns the query as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	return {
-		type 		=> lc($self->type),
-		pattern		=> $self->pattern->as_hash,
-	};
-}
-
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	my $spin	= RDF::Trine::Namespace->new('http://spinrdf.org/spin#');
-	my $xsd		= RDF::Trine::Namespace->new('http://www.w3.org/2001/XMLSchema#');
-	my $q		= $self->pattern->as_spin( $model );
-	
-	$model->add_statement( RDF::Trine::Statement->new($q, $spin->distinct, RDF::Query::Node::Literal->new('true', undef, $xsd->boolean)) );
-	
-	return $q;
+	# we don't add 'DISTINCT' here because it would be in the wrong place.
+	# RDF::Query::as_sparql() adds it outside the pattern serialization
+	# along with projection and 'SELECT'.
+	return $self->pattern->as_sparql( $context, $indent );
 }
 
 =item C<< type >>
@@ -165,19 +124,7 @@ Returns a list of the variable names used in this algebra expression.
 
 sub referenced_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq($self->pattern->referenced_variables);
-}
-
-=item C<< potentially_bound >>
-
-Returns a list of the variable names used in this algebra expression that will
-bind values during execution.
-
-=cut
-
-sub potentially_bound {
-	my $self	= shift;
-	return $self->pattern->potentially_bound;
+	return uniq($self->pattern->referenced_variables);
 }
 
 =item C<< definite_variables >>
@@ -191,14 +138,52 @@ sub definite_variables {
 	return $self->pattern->definite_variables;
 }
 
-=item C<< is_solution_modifier >>
+=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
 
-Returns true if this node is a solution modifier.
+Returns a new pattern that is ready for execution using the given bridge.
+This method replaces generic node objects with bridge-native objects.
 
 =cut
 
-sub is_solution_modifier {
-	return 1;
+sub fixup {
+	my $self	= shift;
+	my $class	= ref($self);
+	my $query	= shift;
+	my $bridge	= shift;
+	my $base	= shift;
+	my $ns		= shift;
+	
+	if (my $opt = $bridge->fixup( $self, $query, $base, $ns )) {
+		return $opt;
+	} else {
+		return $class->new( $self->pattern->fixup( $query, $bridge, $base, $ns ) );
+	}
+}
+
+=item C<< execute ( $query, $bridge, \%bound, $context, %args ) >>
+
+=cut
+
+sub execute {
+	my $self		= shift;
+	my $query		= shift;
+	my $bridge		= shift;
+	my $bound		= shift;
+	my $context		= shift;
+	my %args		= @_;
+	
+	my $stream		= $self->pattern->execute( $query, $bridge, $bound, $context, %args );
+	
+	my %seen;
+	my @variables	= $query->variables;
+	$stream	= sgrep {
+		my $row	= $_;
+		no warnings 'uninitialized';
+		my $key	= join($;, map {$bridge->as_string( $_ )} map { $row->{$_} } @variables);
+		return (not $seen{ $key }++);
+	} $stream;
+	
+	return $stream;
 }
 
 
