@@ -5,10 +5,6 @@
 
 RDF::Query::Algebra::Filter - Algebra class for Filter expressions
 
-=head1 VERSION
-
-This document describes RDF::Query::Algebra::Filter version 2.917_01.
-
 =cut
 
 package RDF::Query::Algebra::Filter;
@@ -19,6 +15,7 @@ no warnings 'redefine';
 use base qw(RDF::Query::Algebra);
 
 use Data::Dumper;
+use List::MoreUtils qw(uniq);
 use Carp qw(carp croak confess);
 use Scalar::Util qw(blessed reftype);
 
@@ -27,9 +24,10 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
@@ -42,9 +40,6 @@ BEGIN {
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -102,86 +97,48 @@ Returns the filter pattern.
 sub pattern {
 	my $self	= shift;
 	if (@_) {
-		$self->[2]	= shift;
+		my $pattern	= shift;
+		Carp::confess unless ($pattern->isa('RDF::Query::Algebra::GroupGraphPattern'));
+		$self->[2]	= $pattern;
 	}
 	return $self->[2];
 }
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
 sub sse {
 	my $self	= shift;
 	my $context	= shift;
-	my $prefix	= shift || '';
-	my $indent	= $context->{indent} || '  ';
 	
 	return sprintf(
-		"(filter %s\n${prefix}${indent}%s)",
-		$self->expr->sse( $context, "${prefix}${indent}" ),
-		$self->pattern->sse( $context, "${prefix}${indent}" ),
+		'(filter %s %s)',
+		$self->expr->sse( $context ),
+		$self->pattern->sse( $context ),
 	);
 }
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
 sub as_sparql {
 	my $self	= shift;
-	my $context	= shift || {};
-	my $indent	= shift || '';
-	
-	if ($context->{ skip_filter }) {
-		$context->{ skip_filter }--;
-		return $self->pattern->as_sparql( $context, $indent );
-	}
+	my $context	= shift;
+	my $indent	= shift;
 	
 	my $expr	= $self->expr;
 	my $filter_sparql	= $expr->as_sparql( $context, $indent );
 	my $pattern_sparql	= $self->pattern->as_sparql( $context, $indent );
-	if ($pattern_sparql =~ m#}\s*$#) {
-		$pattern_sparql		=~ s#}\s*$#${indent}\tFILTER( ${filter_sparql} ) .\n${indent}}#;
-	} else {
-		$pattern_sparql		= "${pattern_sparql}\n${indent}FILTER( ${filter_sparql} )";
-	}
+	$pattern_sparql		=~ s#}\s*$#${indent}\tFILTER ${filter_sparql} .\n${indent}}#;
 	return $pattern_sparql;
 }
 
-=item C<< as_hash >>
-
-Returns the query as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	return {
-		type 		=> lc($self->type),
-		pattern		=> $self->pattern->as_hash,
-		expression	=> $self->expr->as_hash,
-	};
-}
-
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	return $self->pattern->as_spin($model);
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -204,26 +161,14 @@ sub referenced_variables {
 	my $pattern	= $self->pattern;
 	my @vars	= $pattern->referenced_variables;
 	if (blessed($expr) and $expr->isa('RDF::Query::Algebra')) {
-		return RDF::Query::_uniq(@vars, $self->expr->referenced_variables);
+		return uniq(@vars, $self->expr->referenced_variables);
 	} elsif (blessed($expr) and $expr->isa('RDF::Query::Node::Variable')) {
-		return RDF::Query::_uniq(@vars, $expr->name);
+		return uniq(@vars, $expr->name);
 	} else {
 		return (@vars);
 	}
 }
 
-=item C<< potentially_bound >>
-
-Returns a list of the variable names used in this algebra expression that will
-bind values during execution.
-
-=cut
-
-sub potentially_bound {
-	my $self	= shift;
-	return $self->pattern->potentially_bound;
-}
-
 =item C<< definite_variables >>
 
 Returns a list of the variable names that will be bound after evaluating this algebra expression.
@@ -236,16 +181,61 @@ sub definite_variables {
 	return $pattern->definite_variables;
 }
 
-=item C<< is_solution_modifier >>
+=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
 
-Returns true if this node is a solution modifier.
+Returns a new pattern that is ready for execution using the given bridge.
+This method replaces generic node objects with bridge-native objects.
 
 =cut
 
-sub is_solution_modifier {
-	return 0;
+sub fixup {
+	my $self	= shift;
+	my $class	= ref($self);
+	my $query	= shift;
+	my $bridge	= shift;
+	my $base	= shift;
+	my $ns		= shift;
+	
+	if (my $opt = $bridge->fixup( $self, $query, $base, $ns )) {
+		return $opt;
+	} else {
+		my $expr	= $self->expr;
+		if ($expr->isa('RDF::Query::Algebra')) {
+			$expr	= $expr->fixup( $query, $bridge, $base, $ns );
+		}
+		my $pattern	= $self->pattern->fixup( $query, $bridge, $base, $ns );
+		return $class->new( $expr, $pattern );
+	}
 }
 
+=item C<< execute ( $query, $bridge, \%bound, $context, %args ) >>
+
+=cut
+
+sub execute {
+	my $self		= shift;
+	my $query		= shift;
+	my $bridge		= shift;
+	my $bound		= shift;
+	my $context		= shift;
+	my %args		= @_;
+	
+	my $expr		= $self->expr;
+	my $bool		= RDF::Query::Node::Resource->new( "sparql:ebv" );
+	my $filter		= RDF::Query::Expression::Function->new( $bool, $expr );
+	my $pattern		= $self->pattern;
+	my $stream		= sgrep {
+						my $bound	= $_;
+						my $bool	= 0;
+						eval {
+							my $value	= $filter->evaluate( $query, $bridge, $bound );
+							$bool	= ($value->literal_value eq 'true') ? 1 : 0;
+						};
+						return $bool;
+					} $pattern->execute( $query, $bridge, $bound, $context, %args );
+}
+
+
 
 1;
 
