@@ -5,10 +5,6 @@
 
 RDF::Query::Algebra::Limit - Algebra class for limiting query results
 
-=head1 VERSION
-
-This document describes RDF::Query::Algebra::Limit version 2.917_01.
-
 =cut
 
 package RDF::Query::Algebra::Limit;
@@ -21,23 +17,22 @@ use base qw(RDF::Query::Algebra);
 use Data::Dumper;
 use Set::Scalar;
 use Scalar::Util qw(blessed);
+use List::MoreUtils qw(uniq);
 use Carp qw(carp croak confess);
 use RDF::Trine::Iterator qw(sgrep);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -77,9 +72,6 @@ Returns the pattern to be sorted.
 
 sub pattern {
 	my $self	= shift;
-	if (@_) {
-		$self->[0]	= shift;
-	}
 	return $self->[0];
 }
 
@@ -96,36 +88,24 @@ sub limit {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
 sub sse {
 	my $self	= shift;
 	my $context	= shift;
-	my $prefix	= shift || '';
-	my $indent	= $context->{indent} || '  ';
 	
-	if ($self->pattern->isa('RDF::Query::Algebra::Offset')) {
-		my $l	= $self->limit;
-		my $o	= $self->pattern->offset;
-		return sprintf(
-			"(slice %d %d\n${prefix}${indent}%s)",
-			$o, $l,
-			$self->pattern->pattern->sse( $context, "${prefix}${indent}" ),
-		);
-	} else {
-		return sprintf(
-			"(limit %s\n${prefix}${indent}%s)",
-			$self->limit,
-			$self->pattern->sse( $context, "${prefix}${indent}" ),
-		);
-	}
+	return sprintf(
+		'(limit %s %s)',
+		$self->pattern->sse( $context ),
+		$self->limit,
+	);
 }
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -142,22 +122,6 @@ sub as_sparql {
 	return $string;
 }
 
-=item C<< as_hash >>
-
-Returns the query as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	return {
-		type 		=> lc($self->type),
-		pattern		=> $self->pattern->as_hash,
-		limit		=> $self->limit,
-	};
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -176,19 +140,7 @@ Returns a list of the variable names used in this algebra expression.
 
 sub referenced_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq($self->pattern->referenced_variables);
-}
-
-=item C<< potentially_bound >>
-
-Returns a list of the variable names used in this algebra expression that will
-bind values during execution.
-
-=cut
-
-sub potentially_bound {
-	my $self	= shift;
-	return $self->pattern->potentially_bound;
+	return uniq($self->pattern->referenced_variables);
 }
 
 =item C<< definite_variables >>
@@ -202,14 +154,45 @@ sub definite_variables {
 	return $self->pattern->definite_variables;
 }
 
-=item C<< is_solution_modifier >>
+=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
 
-Returns true if this node is a solution modifier.
+Returns a new pattern that is ready for execution using the given bridge.
+This method replaces generic node objects with bridge-native objects.
 
 =cut
 
-sub is_solution_modifier {
-	return 1;
+sub fixup {
+	my $self	= shift;
+	my $class	= ref($self);
+	my $query	= shift;
+	my $bridge	= shift;
+	my $base	= shift;
+	my $ns		= shift;
+	
+	if (my $opt = $bridge->fixup( $self, $query, $base, $ns )) {
+		return $opt;
+	} else {
+		return $class->new( $self->pattern->fixup( $query, $bridge, $base, $ns ), $self->limit );
+	}
+}
+
+=item C<< execute ( $query, $bridge, \%bound, $context, %args ) >>
+
+=cut
+
+sub execute {
+	my $self		= shift;
+	my $query		= shift;
+	my $bridge		= shift;
+	my $bound		= shift;
+	my $context		= shift;
+	my %args		= @_;
+	
+	my $limit		= $self->limit;
+	my $stream		= $self->pattern->execute( $query, $bridge, $bound, $context, %args );
+	
+	my $count		= 0;
+	return sgrep { $count++ < $limit } $stream;
 }
 
 
