@@ -5,10 +5,6 @@
 
 RDF::Query::Algebra::NamedGraph - Algebra class for NamedGraph patterns
 
-=head1 VERSION
-
-This document describes RDF::Query::Algebra::NamedGraph version 2.917_01.
-
 =cut
 
 package RDF::Query::Algebra::NamedGraph;
@@ -17,28 +13,27 @@ use strict;
 use warnings;
 no warnings 'redefine';
 use base qw(RDF::Query::Algebra);
+use constant DEBUG	=> 0;
 
 use Data::Dumper;
-use Log::Log4perl;
 use RDF::Query::Error;
+use List::MoreUtils qw(uniq);
 use Carp qw(carp croak confess);
 use Scalar::Util qw(blessed reftype);
 use RDF::Trine::Iterator qw(sgrep smap swatch);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -95,126 +90,41 @@ sub pattern {
 	return $self->[2];
 }
 
-=item C<< quads >>
-
-Returns a list of the quads belonging to this NamedGraph.
-
-=cut
-
-sub quads {
-	my $self	= shift;
-	my @quads;
-	foreach my $p ($self->subpatterns_of_type('RDF::Query::Algebra::BasicGraphPattern')) {
-		push(@quads, $p->quads);
-	}
-	my @graphquads;
-	foreach my $q (@quads) {
-		my $st	= RDF::Trine::Statement::Quad->new(
-					$q->subject,
-					$q->predicate,
-					$q->object,
-					$self->graph,
-				);
-		push(@graphquads, $st);
-	}
-	return @graphquads;
-}
-
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
 sub sse {
 	my $self	= shift;
 	my $context	= shift;
-	my $prefix	= shift || '';
-	my $indent	= $context->{indent} || '';
 	
 	return sprintf(
-		"(namedgraph\n${prefix}${indent}%s\n${prefix}${indent}%s)",
-		$self->graph->sse( $context, "${prefix}${indent}" ),
-		$self->pattern->sse( $context, "${prefix}${indent}" )
+		'(namedgraph %s %s)',
+		$self->graph->sse( $context ),
+		$self->pattern->sse( $context )
 	);
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the algebra appropriate for display on the
-command line.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my $s		= shift;
-	my $count	= shift;
-	my $indent	= $s x $count;
-	my $string	= "${indent}named graph pattern\n"
-				. "${indent}${s}graph: " . $self->graph->as_string . "\n"
-				. $self->pattern->explain( $s, $count+1 );
-	return $string;
-}
-
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
 sub as_sparql {
 	my $self	= shift;
-	my $context	= shift || {};
+	my $context	= shift;
 	my $indent	= shift;
-	my $pcontext	= { %$context, force_ggp_braces => 1 };
-	
 	my $string	= sprintf(
 		"GRAPH %s %s",
 		$self->graph->as_sparql( $context, $indent ),
-		$self->pattern->as_sparql( $pcontext, $indent ),
+		$self->pattern->as_sparql( $context, $indent ),
 	);
 	return $string;
 }
 
-=item C<< as_hash >>
-
-Returns the query as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	return {
-		type 		=> lc($self->type),
-		graph		=> $self->graph,
-		pattern		=> $self->pattern->as_hash,
-	};
-}
-
-=item C<< as_spin ( $model ) >>
-
-Adds statements to the given model to represent this algebra object in the
-SPARQL Inferencing Notation (L<http://www.spinrdf.org/>).
-
-=cut
-
-sub as_spin {
-	my $self	= shift;
-	my $model	= shift;
-	my $spin	= RDF::Trine::Namespace->new('http://spinrdf.org/spin#');
-	my $rdf		= RDF::Trine::Namespace->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#');
-	my @t		= $self->pattern->as_spin( $model );
-	
-	my $ng		= RDF::Query::Node::Blank->new();
-	my $list	= $model->add_list( @t );
-	$model->add_statement( RDF::Trine::Statement->new($ng, $rdf->type, $spin->NamedGraph) );
-	$model->add_statement( RDF::Trine::Statement->new($ng, $spin->elements, $list) );
-	
-	return $ng;
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -233,29 +143,13 @@ Returns a list of the variable names used in this algebra expression.
 
 sub referenced_variables {
 	my $self	= shift;
-	my @list	= RDF::Query::_uniq(
+	my @list	= uniq(
 		$self->pattern->referenced_variables,
 		(map { $_->name } grep { $_->isa('RDF::Query::Node::Variable') } ($self->graph)),
 	);
 	return @list;
 }
 
-=item C<< potentially_bound >>
-
-Returns a list of the variable names used in this algebra expression that will
-bind values during execution.
-
-=cut
-
-sub potentially_bound {
-	my $self	= shift;
-	my @list	= RDF::Query::_uniq(
-		$self->pattern->potentially_bound,
-		(map { $_->name } grep { $_->isa('RDF::Query::Node::Variable') } ($self->graph)),
-	);
-	return @list;
-}
-
 =item C<< definite_variables >>
 
 Returns a list of the variable names that will be bound after evaluating this algebra expression.
@@ -264,14 +158,14 @@ Returns a list of the variable names that will be bound after evaluating this al
 
 sub definite_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq(
-		$self->pattern->definite_variables,
+	return uniq(
 		map { $_->name } grep { $_->isa('RDF::Query::Node::Variable') } ($self->graph),
+		$self->pattern->definite_variables,
 	);
 }
 
 
-=item C<< qualify_uris ( \%namespaces, $base_uri ) >>
+=item C<< qualify_uris ( \%namespaces, $base ) >>
 
 Returns a new algebra pattern where all referenced Resource nodes representing
 QNames (ns:local) are qualified using the supplied %namespaces.
@@ -282,9 +176,9 @@ sub qualify_uris {
 	my $self	= shift;
 	my $class	= ref($self);
 	my $ns		= shift;
-	my $base_uri	= shift;
+	my $base	= shift;
 	
-	my $pattern	= $self->pattern->qualify_uris( $ns, $base_uri );
+	my $pattern	= $self->pattern->qualify_uris( $ns, $base );
 	my $graph	= $self->graph;
 	if (blessed($graph) and $graph->isa('RDF::Query::Node::Resource')) {
 		my $uri	= $graph->uri;
@@ -294,38 +188,62 @@ sub qualify_uris {
 				throw RDF::Query::Error::QuerySyntaxError -text => "Namespace $n is not defined";
 			}
 			my $resolved	= join('', $ns->{ $n }, $l);
-			$graph			= RDF::Query::Node::Resource->new( $resolved, $base_uri );
+			$graph			= RDF::Query::Node::Resource->new( $resolved, $base );
 		}
 	}
 	return $class->new( $graph, $pattern );
 }
 
-=item C<< check_duplicate_blanks >>
 
-Returns true if blank nodes respect the SPARQL rule of no blank-label re-use
-across BGPs, otherwise throws a RDF::Query::Error::QueryPatternError exception.
+=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
+
+Returns a new pattern that is ready for execution using the given bridge.
+This method replaces generic node objects with bridge-native objects.
 
 =cut
 
-sub check_duplicate_blanks {
+sub fixup {
 	my $self	= shift;
-	my @data;
-	foreach my $arg ($self->construct_args) {
-		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
-			push(@data, $arg->_referenced_blanks());
-		}
-	}
+	my $class	= ref($self);
+	my $query	= shift;
+	my $bridge	= shift;
+	my $base	= shift;
+	my $ns		= shift;
 	
-	my %seen;
-	foreach my $d (@data) {
-		foreach my $b (@$d) {
-			if ($seen{ $b }++) {
-				throw RDF::Query::Error::QueryPatternError -text => "Same blank node identifier ($b) used in more than one BasicGraphPattern.";
-			}
-		}
+	if (my $opt = $bridge->fixup( $self, $query, $base, $ns )) {
+		return $opt;
+	} else {
+		my $graph	= ($self->graph->isa('RDF::Query::Node'))
+					? $bridge->as_native( $self->graph )
+					: $self->graph->fixup( $query, $bridge, $base, $ns );
+		
+		my $pattern	= $self->pattern->fixup( $query, $bridge, $base, $ns );
+		return $class->new( $graph, $pattern );
 	}
+}
+
+=item C<< execute ( $query, $bridge, \%bound, $context, %args ) >>
+
+=cut
+
+sub execute {
+	my $self		= shift;
+	my $query		= shift;
+	my $bridge		= shift;
+	my $bound		= shift;
+	my $outer_ctx	= shift;
+	my %args		= @_;
 	
-	return 1;
+	if ($outer_ctx) {
+		throw RDF::Query::Error::QueryPatternError ( -text => "Can't use nested named graphs" );
+	}
+
+	my $context			= $self->graph;
+	my $named_triples	= $self->pattern;
+	
+	_debug( 'named triples: ' . Dumper($named_triples), 1 ) if (DEBUG);
+	my $nstream	= $named_triples->execute( $query, $bridge, $bound, $context, %args );
+	return $nstream;
 }
 
 1;
