@@ -5,10 +5,6 @@
 
 RDF::Query::Algebra::TimeGraph - Algebra class for temporal patterns
 
-=head1 VERSION
-
-This document describes RDF::Query::Algebra::TimeGraph version 2.917_01.
-
 =cut
 
 package RDF::Query::Algebra::TimeGraph;
@@ -19,22 +15,21 @@ no warnings 'redefine';
 use base qw(RDF::Query::Algebra);
 
 use Data::Dumper;
+use List::MoreUtils qw(uniq);
 use Carp qw(carp croak confess);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -102,27 +97,25 @@ sub time_triples {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
 sub sse {
 	my $self	= shift;
 	my $context	= shift;
-	my $prefix	= shift || '';
-	my $indent	= $context->{indent};
 	
 	return sprintf(
-		'(time\n${prefix}${indent}%s\n${prefix}${indent}%s\n${prefix}${indent}%s)',
-		$self->interval->sse( $context, "${prefix}${indent}" ),
-		$self->pattern->sse( $context, "${prefix}${indent}" ),
-		$self->time_triples->sse( $context, "${prefix}${indent}" ),
+		'(time %s %s %s)',
+		$self->interval->sse( $context ),
+		$self->pattern->sse( $context ),
+		$self->time_triples->sse( $context ),
 	);
 }
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -157,29 +150,13 @@ Returns a list of the variable names used in this algebra expression.
 
 sub referenced_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq(
+	return uniq(
 		map { $_->name } grep { $_->isa('RDF::Query::Node::Variable') } ($self->graph),
 		$self->pattern->referenced_variables,
 		$self->time_triples->referenced_variables,
 	);
 }
 
-=item C<< potentially_bound >>
-
-Returns a list of the variable names used in this algebra expression that will
-bind values during execution.
-
-=cut
-
-sub potentially_bound {
-	my $self	= shift;
-	return RDF::Query::_uniq(
-		map { $_->name } grep { $_->isa('RDF::Query::Node::Variable') } ($self->graph),
-		$self->pattern->potentially_bound,
-		$self->time_triples->potentially_bound,
-	);
-}
-
 =item C<< definite_variables >>
 
 Returns a list of the variable names that will be bound after evaluating this algebra expression.
@@ -188,7 +165,7 @@ Returns a list of the variable names that will be bound after evaluating this al
 
 sub definite_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq(
+	return uniq(
 		map { $_->name } grep { $_->isa('RDF::Query::Node::Variable') } ($self->graph),
 		$self->pattern->definite_variables,
 		$self->time_triples->definite_variables,
