@@ -5,10 +5,6 @@
 
 RDF::Query::Algebra::Union - Algebra class for Union patterns
 
-=head1 VERSION
-
-This document describes RDF::Query::Algebra::Union version 2.917_01.
-
 =cut
 
 package RDF::Query::Algebra::Union;
@@ -20,24 +16,22 @@ use base qw(RDF::Query::Algebra);
 
 use Data::Dumper;
 use Set::Scalar;
-use Log::Log4perl;
 use Scalar::Util qw(blessed);
+use List::MoreUtils qw(uniq);
 use Carp qw(carp croak confess);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Algebra> class.
-
 =over 4
 
 =cut
@@ -103,26 +97,24 @@ sub second {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
 sub sse {
 	my $self	= shift;
 	my $context	= shift;
-	my $prefix	= shift || '';
-	my $indent	= $context->{indent} || '  ';
 	
 	return sprintf(
-		"(union\n${prefix}${indent}%s\n${prefix}${indent}%s)",
-		$self->first->sse( $context, "${prefix}${indent}" ),
-		$self->second->sse( $context, "${prefix}${indent}" )
+		'(union %s %s)',
+		$self->first->sse( $context ),
+		$self->second->sse( $context )
 	);
 }
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -132,27 +124,12 @@ sub as_sparql {
 	my $indent	= shift;
 	my $string	= sprintf(
 		"%s\n${indent}UNION\n${indent}%s",
-		$self->first->as_sparql( { %$context, force_ggp_braces => 1 }, $indent ),
-		$self->second->as_sparql( { %$context, force_ggp_braces => 1 }, $indent ),
+		$self->first->as_sparql( $context, $indent ),
+		$self->second->as_sparql( $context, $indent ),
 	);
 	return $string;
 }
 
-=item C<< as_hash >>
-
-Returns the query as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	return {
-		type 		=> lc($self->type),
-		patterns	=> [ map { $_->as_hash } $self->patterns ],
-	};
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -171,19 +148,7 @@ Returns a list of the variable names used in this algebra expression.
 
 sub referenced_variables {
 	my $self	= shift;
-	return RDF::Query::_uniq($self->first->referenced_variables, $self->second->referenced_variables);
-}
-
-=item C<< potentially_bound >>
-
-Returns a list of the variable names used in this algebra expression that will
-bind values during execution.
-
-=cut
-
-sub potentially_bound {
-	my $self	= shift;
-	return RDF::Query::_uniq($self->first->potentially_bound, $self->second->potentially_bound);
+	return uniq($self->first->referenced_variables, $self->second->referenced_variables);
 }
 
 =item C<< definite_variables >>
@@ -199,6 +164,68 @@ sub definite_variables {
 	return $seta->intersection( $setb )->members;
 }
 
+=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
+
+Returns a new pattern that is ready for execution using the given bridge.
+This method replaces generic node objects with bridge-native objects.
+
+=cut
+
+sub fixup {
+	my $self	= shift;
+	my $class	= ref($self);
+	my $query	= shift;
+	my $bridge	= shift;
+	my $base	= shift;
+	my $ns		= shift;
+	
+	if (my $opt = $bridge->fixup( $self, $query, $base, $ns )) {
+		return $opt;
+	} else {
+		return $class->new( map { $_->fixup( $query, $bridge, $base, $ns ) } $self->patterns );
+	}
+}
+
+=item C<< execute ( $query, $bridge, \%bound, $context, %args ) >>
+
+=cut
+
+sub execute {
+	my $self		= shift;
+	my $query		= shift;
+	my $bridge		= shift;
+	my $bound		= shift;
+	my $context		= shift;
+	my %args		= @_;
+	
+	my @names;
+	my @streams;
+	foreach my $u_triples ($self->first, $self->second) {
+		my $stream	= $u_triples->execute( $query, $bridge, $bound, $context, %args );
+		
+		if ($debug) {
+			$stream		= $stream->materialize;
+			warn "union stream:\n";
+			while (my $b = $stream->next) {
+				warn "BINDING: " . join(', ', map { my $v = $b->{$_}; join('=', $_, (blessed($v) ? $v->sse : '')) } (keys %$b));
+			}
+			$stream->reset;
+		}
+		
+		push(@names, $stream->binding_names);
+		push(@streams, $stream);
+	}
+	
+	@streams	= map { $_->project( @names ) } @streams;
+	my $stream	= shift(@streams);
+	while (@streams) {
+		$stream	= $stream->concat( shift(@streams), undef, \@names );
+	}
+	
+	return $stream;
+}
+
+
 1;
 
 __END__
