@@ -5,16 +5,6 @@
 
 RDF::Query::Compiler::SQL - Compile a SPARQL query directly to SQL.
 
-=head1 VERSION
-
-This document describes RDF::Query::Compiler::SQL version 2.917_01.
-
-=head1 STATUS
-
-This module's API and functionality should be considered deprecated.
-If you need functionality that this module provides,
-please L<get in touch|http://www.perlrdf.org/>.
-
 =cut
 
 package RDF::Query::Compiler::SQL;
@@ -25,7 +15,6 @@ no warnings 'redefine';
 
 use RDF::Query::Error qw(:try);
 
-use Log::Log4perl;
 use List::Util qw(first);
 use Data::Dumper;
 use Math::BigInt;
@@ -39,9 +28,10 @@ use RDF::Query::Error qw(:try);
 ######################################################################
 
 my (@NODE_TYPE_TABLES, %NODE_TYPE_TABLES);
-our ($VERSION);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 	@NODE_TYPE_TABLES	= (
 							['Resources', 'ljr', 'URI'],
 							['Literals', 'ljl', qw(Value Language Datatype)],
@@ -70,11 +60,10 @@ sub new {
 	my $class	= shift;
 	my $parsed	= shift;
 	my $model	= shift;
-	my $l		= Log::Log4perl->get_logger("rdf.query.compiler.sql");
 	my $stable;
 	if ($model) {
 		my $mhash	= _mysql_hash( $model );
-		$l->debug("Model: $model => $mhash\n");
+		warn "Model: $model => $mhash\n" if ($debug);
 		$stable		= "Statements${mhash}";
 	} else {
 		$stable		= 'Statements';
@@ -267,7 +256,6 @@ contain the node values (for literals, resources, and blank nodes).
 
 sub add_variable_values_joins {
 	my $self	= shift;
-	my $l		= Log::Log4perl->get_logger("rdf.query.algebra.service");
 	my $parsed	= $self->{parsed};
 	my @vars	= map { $_->name } @{ $parsed->{variables} };
 	my %select_vars	= map { $_ => 1 } @vars;
@@ -289,7 +277,7 @@ sub add_variable_values_joins {
 		my $col_table	= (split(/[.]/, $col))[0];
 		my ($count)		= ($col_table =~ /\w(\d+)/);
 		
-		$l->debug("var: $var\t\tcol: $col\t\tcount: $count\t\tunique count: $uniq_count\n");
+		warn "var: $var\t\tcol: $col\t\tcount: $count\t\tunique count: $uniq_count\n" if ($debug);
 		
 		push(@cols, "${col} AS ${var}_Node") if ($select_vars{ $var });
 		foreach (@NODE_TYPE_TABLES) {
@@ -507,9 +495,6 @@ sub patterns2sql {
 			$self->{options}{orderby}	= [ $triple->orderby ];
 			my $pattern	= $triple->pattern;
 			$self->patterns2sql( [ $pattern ], $level, %args );
-		} elsif ($triple->isa('RDF::Query::Algebra::Project')) {
-			my $pattern	= $triple->pattern;
-			$self->patterns2sql( [ $pattern ], $level, %args );
 		} else {
 			throw RDF::Query::Error::CompilationError( -text => "Unknown pattern type '$triple' in SQL compilation." );
 		}
@@ -574,8 +559,8 @@ sub expr2sql {
 	Carp::confess unless ref($expr);
 	
 	my $blessed	= blessed($expr);
-	if ($blessed and $expr->isa('RDF::Trine::Node')) {
-		if ($expr->isa('RDF::Trine::Node::Literal')) {
+	if ($blessed and $expr->isa('RDF::Query::Node')) {
+		if ($expr->isa('RDF::Query::Node::Literal')) {
 			my $literal	= $expr->literal_value;
 			my $dt		= $expr->literal_datatype;
 			
@@ -693,7 +678,7 @@ sub expr2sql {
 						}
 					} else {
 						++$$level; my $sql_a	= $self->expr2sql( $a, $level, equality => $equality );
-						if ($b->type eq 'VAR') {
+						if ($b->[0] eq 'VAR') {
 							# ?var cmp NODE
 							++$$level; my $var_name	= $self->expr2sql( $b, $level, equality => $equality );
 							my $sql_b	= "(SELECT value FROM Literals WHERE ${var_name} = ID LIMIT 1)";
@@ -825,8 +810,8 @@ sub qualify_uri {
 	my $self	= shift;
 	my $uri		= shift;
 	my $parsed	= $self->{parsed};
-	if (ref($uri) and $uri->type eq 'URI') {
-		$uri	= $uri->uri_value;
+	if (ref($uri) and $uri->[0] eq 'URI') {
+		$uri	= $uri->[1];
 	}
 	
 	if (ref($uri)) {
@@ -897,7 +882,7 @@ BEGIN {
 			push(@literal, $self->expr2sql( $args[0], $level ));
 		}
 		
-		if ($args[1]->type eq 'VAR') {
+		if ($args[1][0] eq 'VAR') {
 			my $name	= $args[0][1];
 			push(@pattern, "${name}_Value");
 			push(@pattern, "${name}_URI");
