@@ -7,7 +7,7 @@ RDF::Query::Error - Error classes for RDF::Query.
 
 =head1 VERSION
 
-This document describes RDF::Query::Error version 2.917_01.
+This document describes RDF::Query::Error version 1.001
 
 =head1 SYNOPSIS
 
@@ -35,9 +35,10 @@ use base qw(Error);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
@@ -94,19 +95,6 @@ package RDF::Query::Error::ExecutionError;
 
 use base qw(RDF::Query::Error);
 
-package RDF::Query::Error::RequestedInterruptError;
-
-use base qw(RDF::Query::Error);
-
-package RDF::Query::Error::PermissionError;
-
-use base qw(RDF::Query::Error);
-
-package RDF::Query::Error::UnimplementedError;
-
-use base qw(RDF::Query::Error);
-
-
 
 1;
 
