@@ -5,10 +5,6 @@
 
 RDF::Query::Expression - Class for Expr expressions
 
-=head1 VERSION
-
-This document describes RDF::Query::Expression version 2.917_01.
-
 =cut
 
 package RDF::Query::Expression;
@@ -20,13 +16,15 @@ use base qw(RDF::Query::Algebra);
 
 use Data::Dumper;
 use Scalar::Util qw(blessed);
+use List::MoreUtils qw(uniq);
 use Carp qw(carp croak confess);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
@@ -86,7 +84,7 @@ sub operands {
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -101,47 +99,6 @@ sub sse {
 	);
 }
 
-=item C<< explain >>
-
-Returns a string serialization of the expression appropriate for display on the
-command line. This method is primarily used by the C<< explain >> method of
-the subclasses of RDF::Query::Plan.
-
-=cut
-
-sub explain {
-	my $self	= shift;
-	my $s		= shift;
-	my $count	= shift;
-	my $indent	= $s x $count;
-	my $type	= $self->op;
-	my $string	= "${indent}${type}\n";
-	foreach my $p ($self->operands) {
-		if ($p->can('explain')) {
-			$string	.= $p->explain( $s, $count+1 );
-		} else {
-			$string	.= $p->sse;
-		}
-	}
-	return $string;
-}
-
-=item C<< as_hash >>
-
-Returns the expression as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	return {
-		type 		=> 'expression',
-		operator	=> $self->op,
-		operands	=> [map { $_->as_hash($context) } $self->operands],
-	};
-}
-
 =item C<< type >>
 
 Returns the type of this algebra expression.
@@ -169,29 +126,35 @@ sub referenced_variables {
 			push(@vars, $o->referenced_variables);
 		}
 	}
-	return RDF::Query::_uniq(@vars);
+	return uniq(@vars);
 }
 
-=item C<< nonaggregated_referenced_variables >>
+=item C<< fixup ( $query, $bridge, $base, \%namespaces ) >>
 
-Returns a list of the variable names used in this algebra expression except
-those used as aliases for aggregate operations.
+Returns a new pattern that is ready for execution using the given bridge.
+This method replaces generic node objects with bridge-native objects.
 
 =cut
 
-sub nonaggregated_referenced_variables {
+sub fixup {
 	my $self	= shift;
-	my @ops		= $self->operands;
-	my @vars;
-	foreach my $o (@ops) {
-		if ($o->isa('RDF::Query::Node::Variable::ExpressionProxy')) {
-		} elsif ($o->isa('RDF::Query::Node::Variable')) {
-			push(@vars, $o->name);
-		} elsif ($o->isa('RDF::Query::Expression')) {
-			push(@vars, $o->nonaggregated_referenced_variables);
-		}
+	my $class	= ref($self);
+	my $query	= shift;
+	my $bridge	= shift;
+	my $base	= shift;
+	my $ns		= shift;
+	
+	if (my $opt = $bridge->fixup( $self, $query, $base, $ns )) {
+		return $opt;
+	} else {
+		my @operands	= map {
+			($_->isa('RDF::Query::Algebra'))
+				? $_->fixup( $query, $bridge, $base, $ns )
+				: $_
+		} $self->operands;
+		
+		return $class->new( $self->op, @operands );
 	}
-	return RDF::Query::_uniq(@vars);
 }
 
 1;
