@@ -5,10 +5,6 @@
 
 RDF::Query::Expression::Alias - Class for aliasing expressions with variable names
 
-=head1 VERSION
-
-This document describes RDF::Query::Expression::Alias version 2.917_01.
-
 =cut
 
 package RDF::Query::Expression::Alias;
@@ -20,22 +16,21 @@ use base qw(RDF::Query::Expression);
 
 use Data::Dumper;
 use Scalar::Util qw(blessed);
+use List::MoreUtils qw(uniq);
 use Carp qw(carp croak confess);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Expression> class.
-
 =over 4
 
 =cut
@@ -59,8 +54,7 @@ Returns the variable object of the aliased expression.
 
 sub alias {
 	my $self	= shift;
-	my ($alias)	= $self->operands;
-	return $alias;
+	return $self->op;
 }
 
 =item C<< expression >>
@@ -71,12 +65,12 @@ Returns the expression object of the aliased expression.
 
 sub expression {
 	my $self	= shift;
-	return ($self->operands)[1];
+	return ($self->operands)[0];
 }
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -85,15 +79,15 @@ sub sse {
 	my $context	= shift;
 	
 	return sprintf(
-		'(alias ?%s %s)',
-		$self->name,
-		$self->expression->sse( $context ),
+		'(alias %s %s)',
+		$self->op,
+		map { $_->sse( $context ) } $self->operands,
 	);
 }
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -106,39 +100,23 @@ sub as_sparql {
 	return sprintf("(%s AS %s)", $expr->as_sparql, $alias->as_sparql);
 }
 
-=item C<< evaluate ( $query, \%bound, $context ) >>
+=item C<< evaluate ( $query, $bridge, \%bound ) >>
 
-Evaluates the expression using the supplied bound variables.
-Will return a RDF::Query::Node object.
+Evaluates the expression using the supplied context (bound variables and bridge
+object). Will return a RDF::Query::Node object.
 
 =cut
 
 sub evaluate {
 	my $self	= shift;
 	my $query	= shift;
+	my $bridge	= shift;
 	my $bound	= shift;
-	my $ctx		= shift;
 	my $expr	= $self->expression;
-	my $value	= $query->var_or_expr_value( $bound, $expr, $ctx );
+	my $value	= $query->var_or_expr_value( $bridge, $bound, $expr );
 	return $value;
 }
 
-=item C<< as_hash >>
-
-Returns the alias as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	return {
-		type 		=> 'alias',
-		alias		=> $self->alias->as_hash,
-		expression	=> $self->expression->as_hash,
-	};
-}
-
 
 1;
 
