@@ -5,10 +5,6 @@
 
 RDF::Query::Expression::Unary - Class for unary expressions
 
-=head1 VERSION
-
-This document describes RDF::Query::Expression::Unary version 2.917_01.
-
 =cut
 
 package RDF::Query::Expression::Unary;
@@ -20,29 +16,28 @@ use base qw(RDF::Query::Expression);
 
 use Data::Dumper;
 use Scalar::Util qw(blessed);
+use List::MoreUtils qw(uniq);
 use Carp qw(carp croak confess);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Expression> class.
-
 =over 4
 
 =cut
 
 =item C<< sse >>
 
-Returns the SSE string for this algebra expression.
+Returns the SSE string for this alegbra expression.
 
 =cut
 
@@ -59,7 +54,7 @@ sub sse {
 
 =item C<< as_sparql >>
 
-Returns the SPARQL string for this algebra expression.
+Returns the SPARQL string for this alegbra expression.
 
 =cut
 
@@ -71,37 +66,34 @@ sub as_sparql {
 	return sprintf("($op %s)", map { $_->as_sparql( $context, $indent ) } $self->operands);
 }
 
-=item C<< evaluate ( $query, \%bound ) >>
+=item C<< evaluate ( $query, $bridge, \%bound ) >>
 
-Evaluates the expression using the supplied bound variables.
-Will return a RDF::Query::Node object.
+Evaluates the expression using the supplied context (bound variables and bridge
+object). Will return a RDF::Query::Node object.
 
 =cut
 
 sub evaluate {
 	my $self	= shift;
 	my $query	= shift;
+	my $bridge	= shift;
 	my $bound	= shift;
-	my $context	= shift;
 	my $op		= $self->op;
 	my ($data)	= $self->operands;
-	if ($op eq '+' or $op eq '-') {
-		my $l		= $data->isa('RDF::Query::Algebra')
-					? $data->evaluate( $query, $bound, $context, @_ )
-					: ($data->isa('RDF::Query::Node::Variable'))
-						? $bound->{ $data->name }
-						: $data;
-		
-		my $value;
-		if ($op eq '+') {
-			$value	= $l->numeric_value;
-		} elsif ($op eq '-') {
-			$value	= -1 * $l->numeric_value;
-		}
-		return RDF::Query::Node::Literal->new( $value, undef, $l->literal_datatype );
+	my $l		= $data->isa('RDF::Query::Algebra')
+				? $data->evaluate( $query, $bridge, $bound )
+				: ($data->isa('RDF::Query::Node::Variable'))
+					? $bound->{ $data->name }
+					: $data;
+	
+	my $value;
+	if ($op eq '+') {
+		$value	= $l->numeric_value;
+	} elsif ($op eq '-') {
+		$value	= -1 * $l->numeric_value;
 	} elsif ($op eq '!') {
 		my $alg		= RDF::Query::Expression::Function->new( "sparql:ebv", $data );
-		my $bool	= $alg->evaluate( $query, $bound, $context, @_ );
+		my $bool	= $alg->evaluate( $query, $bridge, $bound );
 		if ($bool->literal_value eq 'true') {
 			return RDF::Query::Node::Literal->new( 'false', undef, 'http://www.w3.org/2001/XMLSchema#boolean' );
 		} else {
@@ -109,8 +101,9 @@ sub evaluate {
 		}
 	} else {
 		warn "unknown unary op: $op";
-		throw RDF::Query::Error::ExecutionError -text => "Unknown unary op '$op'";
+		die;
 	}
+	return RDF::Query::Node::Literal->new( $value, undef, $l->literal_datatype );
 }
 
 
