@@ -5,10 +5,6 @@
 
 RDF::Query::Model - Model base class
 
-=head1 VERSION
-
-This document describes RDF::Query::Model version 2.202_02, released 30 January 2010.
-
 =cut
 
 package RDF::Query::Model;
@@ -17,7 +13,6 @@ use strict;
 use warnings;
 no warnings 'redefine';
 
-use RDF::Trine::Iterator qw(smap);
 use RDF::Query::Error qw(:try);
 
 use Data::Dumper;
@@ -26,9 +21,10 @@ use Carp qw(carp croak confess);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
-	$VERSION	= '2.202_02';
+	$debug		= 1;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
@@ -165,31 +161,9 @@ Returns a string version of the node object.
 sub as_string {
 	my $self	= shift;
 	my $node	= shift;
-	return unless blessed($node);
-	if ($self->isa_resource( $node )) {
-		my $uri	= $node->uri_value;
-		return qq<[$uri]>;
-	} elsif ($self->isa_literal( $node )) {
-		my $value	= $self->literal_value( $node );
-		my $lang	= $self->literal_value_language( $node );
-		my $dt		= $self->literal_datatype( $node );
-		if ($lang) {
-			return qq["$value"\@${lang}];
-		} elsif ($dt) {
-			return qq["$value"^^<$dt>];
-		} else {
-			return qq["$value"];
-		}
-	} elsif ($self->isa_blank( $node )) {
-		my $id	= $self->blank_identifier( $node );
-		return qq[($id)];
-	} elsif (blessed($node) and $node->isa('RDF::Query::Algebra::Triple')) {
-		return $node->as_sparql;
-	} elsif (blessed($node) and $node->isa('RDF::Query::Algebra::Quad')) {
-		return $node->as_string;
-	} else {
-		return;
-	}
+	return undef unless (blessed($node));
+	my $string	= $node->as_string;
+	return $string;
 }
 
 =item C<is_node ( $node )>
@@ -337,22 +311,6 @@ sub blank_identifier {
 	return $node->blank_identifier;
 }
 
-=item C<< equals ( $node_a, $node_b ) >>
-
-Returns true if C<$node_a> and C<$node_b> are equal
-
-=cut
-
-sub equals {
-	my $self	= shift;
-	my $nodea	= shift;
-	my $nodeb	= shift;
-	return 1 if (not(defined($nodea)) and not(defined($nodeb)));
-	return 0 unless blessed($nodea);
-	return $nodea->equal( $nodeb );
-}
-
-
 =item C<< subject ( $statement ) >>
 
 Returns the subject of the statement.
@@ -431,69 +389,7 @@ predicate and objects. Any of the arguments may be undef to match any value.
 
 sub get_statements {
 	my $self	= shift;
-	my $s		= shift;
-	my $p		= shift;
-	my $o		= shift;
-	my $iter	= $self->_get_statements( $s, $p, $o );
-	if (@_) {
-		my $query	= shift;
-		my $bound	= shift;
-		if (my $extra_iter = $self->get_computed_statements( $s, $p, $o, $query, $bound )) {
-			$iter	= $iter->concat( $extra_iter );
-		}
-	}
-	return $iter;
-}
-
-=item C<< get_basic_graph_pattern ( $execution_context, @triples ) >>
-
-Returns a stream object of all variable bindings matching the specified RDF::Trine::Statement objects.
-
-=cut
-
-sub get_basic_graph_pattern {
-	my $self	= shift;
-	my $context	= shift;
-	my @triples	= @_;
-	my $iter	= $self->_get_basic_graph_pattern( @triples );
-	return $iter;
-}
-
-=item C<< get_computed_statements ( $subject, $predicate, $object, $query, \%bound ) >>
-
-Returns a stream object of all computed statements matching the specified subject,
-predicate and objects. Any of the arguments may be undef to match any value.
-
-=cut
-
-sub get_computed_statements {
-	my $self	= shift;
-	my $s		= shift;
-	my $p		= shift;
-	my $o		= shift;
-	my $query	= shift;
-	my $bound	= shift;
-	my $iter;
-	if (blessed($query)) {
-		my $comps	= $query->get_computed_statement_generators;
-		my $l		= Log::Log4perl->get_logger("rdf.query.model");
-		if (@$comps) {
-			$l->debug("finding matching statements from computed statement generators");
-			foreach my $c (@$comps) {
-				my $new	= $c->( $query, $self, $bound, $s, $p, $o );
-				if ($new) {
-					if (not($iter)) {
-						$iter	= $new;
-					} else {
-						$iter	= $iter->concat( $new );
-					}
-				}
-			}
-		} else {
-			$l->debug("no computed statement generators found");
-		}
-		return $iter;
-	}
+	return $self->_get_statements( @_ );
 }
 
 =item C<< get_named_statements ( $subject, $predicate, $object, $context ) >>
@@ -510,12 +406,7 @@ sub get_named_statements {
 	my $p		= shift;
 	my $o		= shift;
 	my $c		= shift;
-	my $iter	= $self->_get_named_statements( $s, $p, $o, $c );
-	if (@_) {
-		my $query	= shift;
-		my $bound	= shift;
-	}
-	return $iter;
+	return $self->_get_named_statements( $s, $p, $o, $c );
 }
 
 
@@ -536,6 +427,8 @@ sub count_statements {
 	my $model	= $self->{'model'};
 	my $stream;
 	
+	my %args	= ( bridge => $self, named => 1 );
+	
 	my $iter	= $model->get_statements( @triple, $context );
 	my $count	= 0;
 	while (my $row = $iter->next) {
@@ -545,25 +438,6 @@ sub count_statements {
 	return $count;
 }
 
-=item C<node_count ( $subj, $pred, $obj )>
-
-Returns a number representing the frequency of statements in the
-model matching the given triple. This number is used in cost analysis
-for query optimization, and has a range of [0, 1] where zero represents
-no matching triples in the model and one represents matching all triples
-in the model.
-
-=cut
-
-sub node_count {
-	my $self	= shift;
-	my $model	= $self->model;
-	my $total	= $self->count_statements();
-	my $count	= $self->count_statements( @_ );
-	return 0 unless ($total);
-	return $count / $total;
-}
-
 =item C<< fixup ( $pattern, $query, $base, \%namespaces ) >>
 
 Called prior to query execution, if the underlying model can optimize
@@ -588,17 +462,11 @@ model) to STDERR.
 sub debug {
 	my $self	= shift;
 	my $stream	= $self->get_statements( map { $self->new_variable($_) } qw(s p o) );
-	my $nstream	= $self->get_named_statements( map { $self->new_variable($_) } qw(s p o c) );
-	my $l		= Log::Log4perl->get_logger("rdf.query.model");
-	$l->debug("DEFAULT GRAPH ------------------------------");
+	warn "------------------------------\n";
 	while (my $st = $stream->next) {
-		$l->debug($self->as_string( $st ));
+		warn $self->as_string( $st );
 	}
-	$l->debug("NAMED GRAPH ------------------------------");
-	while (my $st = $nstream->next) {
-		$l->debug($self->as_string( $st ));
-	}
-	$l->debug("------------------------------");
+	warn "------------------------------\n";
 }
 
 
