@@ -1,16 +1,3 @@
-# RDF::Query::Model::RDFCore
-# -----------------------------------------------------------------------------
-
-=head1 NAME
-
-RDF::Query::Model::RDFCore - An RDF::Query::Model backend for interfacing with an RDF::Core model.
-
-=head1 VERSION
-
-This document describes RDF::Query::Model::RDFCore version 2.202_02, released 30 January 2010.
-
-=cut
-
 package RDF::Query::Model::RDFCore;
 
 use strict;
@@ -20,7 +7,6 @@ use base qw(RDF::Query::Model);
 
 use Carp qw(carp croak);
 
-use Log::Log4perl;
 use Data::Dumper;
 use File::Spec;
 use File::Temp qw(tempfile);
@@ -38,9 +24,10 @@ use RDF::Trine::Statement::Quad;
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug);
 BEGIN {
-	$VERSION	= '2.202_02';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
@@ -93,12 +80,9 @@ resources and blanks).
 =cut
 
 sub meta {
-	my $self	= shift;
-	
 	return {
 		class		=> __PACKAGE__,
 		model		=> 'RDF::Core::Model',
-		store		=> 'RDF::Core::Storage',
 		statement	=> 'RDF::Core::Statement',
 		node		=> 'RDF::Core::Node',
 		resource	=> 'RDF::Core::Resource',
@@ -283,17 +267,8 @@ sub _get_statements {
 	my $self	= shift;
 	my @triple	= splice(@_, 0, 3);
 	
-	for my $i (0, 1) {
-		my $node	= $triple[ $i ];
-		if (blessed($node) and $node->isa('RDF::Trine::Node::Literal')) {
-			# we have to check this manually, because (as of 2008.7.29) RDF::Core
-			# will die if we try to get statements with a literal in the subject
-			# or predicate position.
-			return RDF::Trine::Iterator::Graph->new( [] );
-		}
-	}
-	
 	@triple		= map { _cast_to_rdfcore( $_ ) } @triple;
+	
 	my $enum	= $self->{'model'}->getStmts( @triple );
 	my $stmt	= $enum->getNext;
 	my $finished	= 0;
@@ -521,18 +496,15 @@ model) to STDERR.
 sub debug {
 	my $self	= shift;
 	my $model	= shift || $self->model;
-	my $l		= Log::Log4perl->get_logger("rdf.query.model.rdfcore");
-	if ($l->is_debug) {
-		my $stream	= $model->getStmts();
-		$l->debug("------------------------------");
-		my $statement	= $stream->getFirst;
-		while (defined $statement) {
-			$l->debug($statement->getLabel);
-			$statement = $stream->getNext
-		}
-		$stream->close;
-		$l->debug("------------------------------");
+	my $stream	= $model->getStmts();
+	warn "------------------------------\n";
+	my $statement	= $stream->getFirst;
+	while (defined $statement) {
+		print STDERR $statement->getLabel . "\n";
+		$statement = $stream->getNext
 	}
+	$stream->close;
+	warn "------------------------------\n";
 }
 
 sub _named_graph_models {
