@@ -1,16 +1,3 @@
-# RDF::Query::Model::RDFTrine
-# -----------------------------------------------------------------------------
-
-=head1 NAME
-
-RDF::Query::Model::RDFTrine - An RDF::Query::Model backend for interfacing with an RDF::Trine model.
-
-=head1 VERSION
-
-This document describes RDF::Query::Model::RDFTrine version 2.202_02, released 30 January 2010.
-
-=cut
-
 package RDF::Query::Model::RDFTrine;
 
 use strict;
@@ -20,20 +7,16 @@ use base qw(RDF::Query::Model);
 
 use Carp qw(carp croak confess);
 
-use Log::Log4perl;
 use File::Spec;
 use File::Temp qw(tempfile);
 use Data::Dumper;
 use Scalar::Util qw(blessed reftype refaddr);
 use LWP::UserAgent;
 use Encode;
-use Error qw(:try);
 
-use RDF::Query::Model::RDFTrine::Filter;
 use RDF::Query::Model::RDFTrine::BasicGraphPattern;
 
 use RDF::Trine 0.102;
-use RDF::Trine qw(iri);
 use RDF::Trine::Model;
 use RDF::Trine::Parser;
 use RDF::Trine::Pattern;
@@ -43,9 +26,10 @@ use RDF::Trine::Iterator qw(smap);
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug);
 BEGIN {
-	$VERSION	= '2.202_02';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
@@ -92,24 +76,15 @@ resources and blanks).
 =cut
 
 sub meta {
-	my $self	= shift;
-	my $meta	= {
+	return {
 		class		=> __PACKAGE__,
+		model		=> 'RDF::Trine::Store::DBI',
 		statement	=> 'RDF::Query::Algebra::Triple',
 		node		=> 'RDF::Trine::Node',
 		resource	=> 'RDF::Trine::Node::Resource',
 		literal		=> 'RDF::Trine::Node::Literal',
 		blank		=> 'RDF::Trine::Node::Blank',
 	};
-	
-	if (blessed($self)) {
-		$meta->{ model }	= ref($self->model);
-		$meta->{ store }	= ref($self->model->_store);
-	} else {
-		$meta->{ model }	= 'RDF::Trine::Model';
-		$meta->{ store }	= 'RDF::Trine::Store';
-	}
-	return $meta;
 }
 
 =item C<model ()>
@@ -120,12 +95,57 @@ Returns the underlying model object.
 
 sub model {
 	my $self	= shift;
-	unless (blessed($self)) {
-		throw RDF::Query::Error::MethodInvocationError -text => "RDF::Query::Model::RDFTrine::model() cannot be called as a class method";
-	}
 	return $self->{'model'};
 }
 
+=item C<< equals ( $node_a, $node_b ) >>
+
+Returns true if C<$node_a> and C<$node_b> are equal
+
+=cut
+
+sub equals {
+	my $self	= shift;
+	my $nodea	= shift;
+	my $nodeb	= shift;
+	return $nodea->equal( $nodeb );
+}
+
+
+=item C<as_string ( $node )>
+
+Returns a string version of the node object.
+
+=cut
+
+sub as_string {
+	my $self	= shift;
+	my $node	= shift;
+	return unless blessed($node);
+	if ($self->isa_resource( $node )) {
+		my $uri	= $node->uri_value;
+		return qq<[$uri]>;
+	} elsif ($self->isa_literal( $node )) {
+		my $value	= $self->literal_value( $node );
+		my $lang	= $self->literal_value_language( $node );
+		my $dt		= $self->literal_datatype( $node );
+		if ($lang) {
+			return qq["$value"\@${lang}];
+		} elsif ($dt) {
+			return qq["$value"^^<$dt>];
+		} else {
+			return qq["$value"];
+		}
+	} elsif ($self->isa_blank( $node )) {
+		my $id	= $self->blank_identifier( $node );
+		return qq[($id)];
+	} elsif (blessed($node) and $node->isa('RDF::Query::Algebra::Triple')) {
+		return $node->as_sparql;
+	} else {
+		return;
+	}
+}
+
 =item C<literal_value ( $node )>
 
 Returns the string value of the literal object.
@@ -207,34 +227,19 @@ sub add_uri {
 	my $named		= shift;
 	my $format		= shift || 'guess';
 	
-	unless ($named) {
-		my $model	= $self->model;
-		my $ok		= 0;
-		try {
-			RDF::Trine::Parser->parse_url_into_model( $uri, $model );
-			$ok	= 1;
-		} catch RDF::Trine::Error::ParserError with {};
-		if ($ok) {
-			return;
-		}
-	}
-	
-	my $ua			= LWP::UserAgent->new( agent => "RDF::Query/${RDF::Query::VERSION}" );
+	my $ua		= LWP::UserAgent->new( agent => "RDF::Query/${RDF::Query::VERSION}" );
 	$ua->default_headers->push_header( 'Accept' => "application/rdf+xml;q=0.5, text/turtle;q=0.7, text/xml" );
-	my $resp		= $ua->get( $uri );
+	
+	my $resp	= $ua->get( $uri );
 	unless ($resp->is_success) {
 		warn "No content available from $uri: " . $resp->status_line;
 		return;
 	}
-	my $data		= $resp->content;
-	$data			= decode_utf8( $data );
-	$self->add_string( $data, $uri, $named, $format );
-	
-#	$self->model->_debug;
-	return;
+	my $content	= $resp->content;
+	$self->add_string( $content, $uri, $named, $format );
 }
 
-=item C<add_string ( $data, $base_uri, $named )>
+=item C<add_string ( $data, $base_uri, $named, $format )>
 
 Adds the contents of C<$data> to the model. If C<$named> is true,
 the data is added to the model using C<$base_uri> as the named context.
@@ -246,20 +251,53 @@ sub add_string {
 	my $data	= shift;
 	my $base	= shift;
 	my $named	= shift;
+	my $format	= shift || 'guess';
 	
-	my $graph	= iri( $base );
+	my $graph	= RDF::Query::Node::Resource->new( $base );
 	my $model	= ($named) ? $self->_named_graphs_model : $self->model;
 	
-	my @named	= ($named) ? (context => iri($base)) : ();
-	my $pname	= 'turtle';
-	if ($data =~ /<rdf:RDF/ms) {
-		$pname	= 'rdfxml';
-	} elsif ($data =~ /XHTML[+]RDFa/) {
-		$pname	= 'rdfa';
+# 	our $USE_RAPPER;
+# 	if ($USE_RAPPER) {
+# 		if ($data !~ m/<rdf:RDF/ms) {
+# 			my ($fh, $filename) = tempfile();
+# 			print $fh $data;
+# 			close($fh);
+# 			$data	= do {
+# 								open(my $fh, '-|', "rapper -q -i turtle -o rdfxml $filename") or die $!;
+# 								local($/)	= undef;
+# 								my $data	= <$fh>;
+# 								my $c		= $self->{counter}++;
+# 								$data		=~ s/nodeID="([^"]+)"/nodeID="r${c}r$1"/smg;
+# 								$data;
+# 							};
+# 			unlink($filename);
+# 		}
+# 	}
+	
+	my $handler	= ($named)
+				? sub { my $st	= shift; $model->add_statement( $st, $graph ) }
+				: sub { my $st	= shift; $model->add_statement( $st ) };
+	
+	if ($data =~ m/<rdf:RDF/ms) {
+		my $parser	= RDF::Trine::Parser->new('rdfxml');
+		$parser->parse( $base, $data, $handler );
+# 		
+# 		require RDF::Redland;
+# 		my $uri		= RDF::Redland::URI->new( $base );
+# 		my $parser	= RDF::Redland::Parser->new($format);
+# 		my $stream	= $parser->parse_string_as_stream($data, $uri);
+# 		while ($stream and !$stream->end) {
+# 			my $statement	= $stream->current;
+# 			my $stmt		= ($named)
+# 							? RDF::Query::Algebra::Quad->from_redland( $statement, $graph )
+# 							: RDF::Query::Algebra::Triple->from_redland( $statement );
+# 			$model->add_statement( $stmt );
+# 			$stream->next;
+# 		}
+	} else {
+		my $parser	= RDF::Trine::Parser->new('turtle');
+		$parser->parse( $base, $data, $handler );
 	}
-	my $parser	= RDF::Trine::Parser->new($pname);
-	$parser->parse_into_model( $base, $data, $model, @named );
-	return;
 }
 
 =item C<statement_method_map ()>
@@ -319,13 +357,12 @@ predicate and objects. Any of the arguments may be undef to match any value.
 sub _get_statements {
 	my $self	= shift;
 	my @triple	= splice(@_, 0, 3);
-	my $l		= Log::Log4perl->get_logger("rdf.query.model.rdftrine");
 	
 	my $model	= $self->model;
 	my @nodes	= map { blessed($_) ? $_ : $self->new_variable() } @triple;
-	if ($l->is_trace) {
-		$l->trace("statement pattern: " . Dumper(\@nodes));
-		$l->trace("model contains:");
+	if ($debug) {
+		warn "statement pattern: " . Dumper(\@nodes);
+		warn "model contains:\n";
 		$model->_debug;
 	}
 	my $stream	= smap { _cast_triple_to_local( $_ ) } $model->get_statements( @nodes );
@@ -344,51 +381,13 @@ sub _get_named_statements {
 	my $self	= shift;
 	my @triple	= splice(@_, 0, 3);
 	my $context	= shift;
-	my $l		= Log::Log4perl->get_logger("rdf.query.model.rdftrine");
 	
 	my $model	= $self->_named_graphs_model;
 	my @nodes	= map { $self->is_node($_) ? $_ : $self->new_variable() } (@triple, $context);
-	
-	if ($l->is_trace) {
-		$l->trace("named statement pattern: " . Dumper(\@nodes));
-		$l->trace("model contains:");
-		$model->_debug;
-	}
-
 	my $stream	= smap { _cast_quad_to_local( $_ ) } $model->get_statements( @nodes );
 	return $stream;
 }
 
-=item C<< _get_basic_graph_pattern ( @triples ) >>
-
-Returns a stream object of all variable bindings matching the specified RDF::Trine::Statement objects.
-
-=cut
-
-sub _get_basic_graph_pattern {
-	my $self	= shift;
-	my @triples	= @_;
-	my $model	= ($triples[0]->isa('RDF::Trine::Statement::Quad'))
-				? $self->_named_graphs_model
-				: $self->model;
-	
-	my $l		= Log::Log4perl->get_logger("rdf.query.model.rdftrine");
-	if ($l->is_trace) {
-		$l->trace("get BGP: " . Dumper(\@triples));
-		$l->trace("model contains:");
-		$model->_debug;
-	}
-	
-	my $pattern	= RDF::Trine::Pattern->new( @triples );
-	my $stream	= smap {
-					foreach my $k (keys %$_) {
-						$_->{ $k }	= _cast_to_local($_->{ $k })
-					}
-					$_
-				} $model->get_pattern( $pattern );
-	return $stream;
-}
-
 =item C<< add_statement ( $statement ) >>
 
 Adds the specified C<$statement> to the underlying model.
@@ -415,50 +414,11 @@ sub remove_statement {
 	$model->remove_statement( $stmt );
 }
 
-=item C<count_statements ($subject, $predicate, $object)>
-
-Returns a stream object of all statements matching the specified subject,
-predicate and objects. Any of the arguments may be undef to match any value.
-
-=cut
-
-sub count_statements {
-	my $self	= shift;
-	return $self->model->count_statements( @_ );
-}
-
-=item C<node_count ( $subj, $pred, $obj )>
-
-Returns a number representing the frequency of statements in the
-model matching the given triple. This number is used in cost analysis
-for query optimization, and has a range of [0, 1] where zero represents
-no matching triples in the model and one represents matching all triples
-in the model.
-
-=cut
-
-sub node_count {
-	my $self	= shift;
-	my @nodes	= @_[0..2];
-	foreach my $i (0..2) {
-		if (blessed($nodes[$i]) and $nodes[$i]->isa('RDF::Trine::Node::Variable')) {
-			$nodes[$i]	= undef;
-		}
-	}
-	my $model	= $self->model;
-	my $total	= $self->count_statements();
-	
-	my $count	= $self->count_statements( @nodes );
-	return 0 unless ($total);
-	return $count / $total;
-}
-
 =item C<supports ($feature)>
 
 Returns true if the underlying model supports the named C<$feature>.
 Possible features include:
 
-	* basic_graph_pattern
 	* named_graph
 	* node_counts
 	* temp_model
@@ -469,11 +429,6 @@ Possible features include:
 sub supports {
 	my $self	= shift;
 	my $feature	= shift;
-	my $meta	= $self->meta;
-	if ($meta->{store} eq 'RDF::Trine::Store::Hexastore') {
-		return 1 if ($feature eq 'node_counts');
-	}
-	return 1 if ($feature eq 'basic_graph_pattern');
 	return 1 if ($feature eq 'temp_model');
 	return 1 if ($feature eq 'named_graph');
 	return 1 if ($feature eq 'named_graphs');
@@ -497,105 +452,17 @@ sub fixup {
 	my $query	= shift;
 	my $base	= shift;
 	my $ns		= shift;
-	my $l		= Log::Log4perl->get_logger("rdf.query.model.rdftrine");
 	
-# 	if ($pattern->isa('RDF::Query::Algebra::BasicGraphPattern') and not(scalar(@{$query->get_computed_statement_generators}))) {
-# 		# call fixup on the triples so that they get converted to bridge-native objects
-# 		my @triples		= map { $_->fixup( $query, $self, $base, $ns ) } $pattern->triples;
-# 		my $tpattern	= RDF::Trine::Pattern->new( @triples );
-# 		return RDF::Query::Model::RDFTrine::BasicGraphPattern->new( $tpattern, $pattern );
-# 	} elsif ($pattern->isa('RDF::Query::Algebra::Filter')) {
-	if ($pattern->isa('RDF::Query::Algebra::Filter')) {
-		my $filter	= $pattern;
-		my $ggp	= $filter->pattern;
-		if ($ggp->isa('RDF::Query::Algebra::GroupGraphPattern')) {
-			$l->debug("pattern is a ggp");
-			my @patterns	= $ggp->patterns;
-			if (scalar(@patterns) == 1 and $patterns[0]->isa('RDF::Query::Algebra::BasicGraphPattern')) {
-				$l->debug("'-> pattern is a bgp");
-				my $bgp	= $patterns[0];
-				my $compiled;
-				try {
-					$self->model->_store->_sql_for_pattern( $filter );
-					$compiled	= RDF::Query::Model::RDFTrine::Filter->new( $filter );
-					$l->debug("    '-> filter can be compiled to RDF::Trine");
-					$l->debug("        '-> " . Dumper($compiled));
-				} otherwise {
-					$l->debug("    '-> filter CANNOT be compiled to RDF::Trine");
-				};
-				return $compiled;
-			} else {
-				return;
-			}
-		} else {
-			return;
-		}
+	if ($pattern->isa('RDF::Query::Algebra::BasicGraphPattern')) {
+		# call fixup on the triples so that they get converted to bridge-native objects
+		my @triples		= map { $_->fixup( $query, $self, $base, $ns ) } $pattern->triples;
+		my $tpattern	= RDF::Trine::Pattern->new( @triples );
+		return RDF::Query::Model::RDFTrine::BasicGraphPattern->new( $tpattern, $pattern );
 	} else {
 		return;
 	}
 }
 
-=item C<< cost_naive ( $bgp, $context ) >>
-
-=cut
-
-sub cost_naive {
-	my $self		= shift;
-	my $costmodel	= shift;
-	my $pattern		= shift;
-	my $context		= shift;
-	if ($pattern->isa('RDF::Query::Model::RDFTrine::BasicGraphPattern')) {
-		# XXX hacked constant. this should do something more like ARQ's naive variable counting cost computation.
-		my $card	= $self->cardinality_naive( $costmodel, $pattern, $context );
-		return $card;
-	}
-	return;
-}
-
-=item C<< cardinality_naive ( $bgp, $context ) >>
-
-=cut
-
-sub cardinality_naive {
-	my $self		= shift;
-	my $costmodel	= shift;
-	my $pattern		= shift;
-	my $context		= shift;
-	if ($pattern->isa('RDF::Query::Model::RDFTrine::BasicGraphPattern')) {
-		# XXX hacked constant. this should do something more like ARQ's naive variable counting cost computation.
-		my @t		= $pattern->triples;
-		my $size	= 0.5 * $costmodel->_size;
-		return $size ** scalar(@t);
-	}
-	return;
-}
-
-=item C<< generate_plans ( $algebra, $context ) >>
-
-=cut
-
-sub generate_plans {
-	my $self	= shift;
-	my $class	= ref($self) || $self;
-	my $algebra	= shift;
-	my $context	= shift;
-	my %args	= @_;
-	my $model	= $context->model;
-	my $query	= $context->query;
-	
-	if (blessed($query) and $query->{force_no_optimization}) {
-		return;
-	}
-	
-	if ($algebra->isa('RDF::Query::Algebra::BasicGraphPattern')) {
-		if (not($query) or not(scalar(@{$query->get_computed_statement_generators}))) {
-			my @triples	= map { $_->distinguish_bnode_variables } $algebra->triples;
-			return RDF::Query::Model::RDFTrine::BasicGraphPattern->new( @triples );
-		}
-	}
-	return;
-}
-
 sub _named_graphs_model {
 	my $self	= shift;
 	if ($self->{named_graphs}) {
