@@ -1,16 +1,3 @@
-# RDF::Query::Model::Redland
-# -----------------------------------------------------------------------------
-
-=head1 NAME
-
-RDF::Query::Model::Redland - An RDF::Query::Model backend for interfacing with a Redland model.
-
-=head1 VERSION
-
-This document describes RDF::Query::Model::Redland version 2.202_02, released 30 January 2010.
-
-=cut
-
 package RDF::Query::Model::Redland;
 
 use strict;
@@ -20,7 +7,6 @@ use base qw(RDF::Query::Model);
 
 use Carp qw(carp croak confess);
 
-use Log::Log4perl;
 use File::Spec;
 use Data::Dumper;
 use LWP::UserAgent;
@@ -33,9 +19,10 @@ use RDF::Trine::Statement::Quad;
 
 ######################################################################
 
-our ($VERSION);
+our ($VERSION, $debug);
 BEGIN {
-	$VERSION	= '2.202_02';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
@@ -82,11 +69,9 @@ resources and blanks).
 =cut
 
 sub meta {
-	my $self	= shift;
 	return {
 		class		=> __PACKAGE__,
 		model		=> 'RDF::Redland::Model',
-		store		=> 'RDF::Redland::Storage',
 		statement	=> 'RDF::Redland::Statement',
 		node		=> 'RDF::Redland::Node',
 		resource	=> 'RDF::Redland::Node',
@@ -106,6 +91,22 @@ sub model {
 	return $self->{'model'};
 }
 
+=item C<< equals ( $node_a, $node_b ) >>
+
+Returns true if C<$node_a> and C<$node_b> are equal
+
+=cut
+
+sub equals {
+	my $self	= shift;
+	my $nodea	= shift;
+	my $nodeb	= shift;
+	return 1 if (not(defined($nodea)) and not(defined($nodeb)));
+	return 0 unless blessed($nodea);
+	return $nodea->equal( $nodeb );
+}
+
+
 =item C<add_uri ( $uri, $named, $format )>
 
 Addsd the contents of the specified C<$uri> to the model.
@@ -123,15 +124,15 @@ sub add_uri {
 	my $model		= $self->{model};
 	my $parser		= RDF::Redland::Parser->new($format);
 	
-	my $ua			= LWP::UserAgent->new( agent => "RDF::Query/${RDF::Query::VERSION}" );
+	my $ua		= LWP::UserAgent->new( agent => "RDF::Query/${RDF::Query::VERSION}" );
 	$ua->default_headers->push_header( 'Accept' => "application/rdf+xml;q=0.5, text/turtle;q=0.7, text/xml" );
 	
-	my $resp		= $ua->get( $uri );
+	my $resp	= $ua->get( $uri );
 	unless ($resp->is_success) {
 		warn "No content available from $uri: " . $resp->status_line;
 		return;
 	}
-	my $data		= $resp->content;
+	my $data	= $resp->content;
 	$data			= decode_utf8( $data );
 	$self->add_string( $data, $uri, $named, $format );
 }
@@ -149,7 +150,6 @@ sub add_string {
 	my $base	= shift;
 	my $named	= shift;
 	my $format	= shift || 'guess';
-	my $l		= Log::Log4perl->get_logger("rdf.query.model.redland");
 	
 	my $model	= ($named) ? $self->_named_graphs_model : $self->model;
 	
@@ -158,7 +158,7 @@ sub add_string {
 	my $redlanduri	= RDF::Redland::URI->new( $base );
 	
 	if ($named) {
-		$l->debug("adding named data with name ($base) to model " . Dumper($model) . ": $data\n");
+		warn "adding named data with name ($base) to model " . Dumper($model) . ": $data\n" if ($debug);
 		my $stream		= $parser->parse_string_as_stream($data, $redlanduri);
 		$model->add_statements( $stream, $redlanduri );
 	} else {
@@ -532,32 +532,30 @@ model) to STDERR.
 sub debug {
 	my $self	= shift;
 	my $model	= shift || $self->model;
-	my $l		= Log::Log4perl->get_logger("rdf.query.model.redland");
 	my $stream	= $self->model_as_stream( $model );
-	$l->debug("------------------------------");
+	warn "------------------------------\n";
 	while (my $st = $stream->current) {
 		my $string	= $self->as_string( $st );
 		if (my $c 	= $stream->context) {
 			my $cs	= $c->as_string;
 			$string	.= "\tC<$cs>";
 		}
-		$l->debug($string);
+		print STDERR "$string\n";
 		$stream->next;
 	}
-	$l->debug("------------------------------");
+	warn "------------------------------\n";
 }
 
 sub _named_graphs_model {
 	my $self	= shift;
-	my $l		= Log::Log4perl->get_logger("rdf.query.model.redland");
 	if ($self->{named_graphs}) {
-		$l->debug("named graphs model: " . Dumper($self->{named_graphs}));
+		warn "named graphs model: " . Dumper($self->{named_graphs}) if ($debug);
 		return $self->{named_graphs};
 	} else {
 		my $storage	= RDF::Redland::Storage->new( "hashes", "test", "new='yes',hash-type='memory',contexts='yes'" );
 		my $model	= RDF::Redland::Model->new( $storage, '' );
 		$self->{named_graphs}	= $model;
-		$l->debug("creating new graphs model: " . Dumper($self->{named_graphs}));
+		warn "creating new graphs model: " . Dumper($self->{named_graphs}) if ($debug);
 		return $model;
 	}
 }
