@@ -5,10 +5,6 @@
 
 RDF::Query::Node::Literal - RDF Node class for literals
 
-=head1 VERSION
-
-This document describes RDF::Query::Node::Literal version 2.917_01.
-
 =cut
 
 package RDF::Query::Node::Literal;
@@ -19,18 +15,18 @@ no warnings 'redefine';
 use base qw(RDF::Query::Node RDF::Trine::Node::Literal);
 
 use DateTime;
-use DateTime::Format::W3CDTF;
+use RDF::Query;
 use RDF::Query::Error;
 use Data::Dumper;
-use Log::Log4perl;
 use Scalar::Util qw(blessed refaddr looks_like_number);
 use Carp qw(carp croak confess);
 
 ######################################################################
 
-our ($VERSION, $LAZY_COMPARISONS);
+our ($VERSION, $debug, $LAZY_COMPARISONS);
 BEGIN {
-	$VERSION	= '2.917_01';
+	$debug		= 0;
+	$VERSION	= '2.001';
 }
 
 ######################################################################
@@ -49,9 +45,6 @@ my %INSIDE_OUT_DATES;
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Node> and L<RDF::Trine::Node::Literal> classes.
-
 =over 4
 
 =cut
@@ -59,13 +52,12 @@ L<RDF::Query::Node> and L<RDF::Trine::Node::Literal> classes.
 sub _cmp {
 	my $nodea	= shift;
 	my $nodeb	= shift;
-	my $op		= shift;
+	my $op	= shift;
 	
-	my $l		= Log::Log4perl->get_logger("rdf.query.node.literal");
-	$l->debug('literal comparison: ' . Dumper($nodea, $nodeb));
+	warn '-------------------------------' if ($debug);
+	warn 'literal comparison: ' . Dumper($nodea, $nodeb) if ($debug);
 	
 	return 1 unless blessed($nodeb);
-	return -1 if ($nodeb->isa('RDF::Trine::Node::Nil'));
 	return 1 if ($nodeb->isa('RDF::Query::Node::Blank'));
 	return 1 if ($nodeb->isa('RDF::Query::Node::Resource'));
 	return 1 unless ($nodeb->isa('RDF::Query::Node::Literal'));
@@ -75,28 +67,20 @@ sub _cmp {
 	my $datetype	= '^http://www.w3.org/2001/XMLSchema#dateTime';
 	my $datecmp		= ($dta =~ $datetype and $dtb =~ $datetype);
 	my $numericcmp	= ($nodea->is_numeric_type and $nodeb->is_numeric_type);
-	
+
 	if ($datecmp) {
-		$l->trace('datecmp');
+		warn 'datecmp' if ($debug);
 		my $datea	= $nodea->datetime;
 		my $dateb	= $nodeb->datetime;
-		if ($datea and $dateb) {
-			my $cmp		= eval { DateTime->compare_ignore_floating( $datea, $dateb ) };
-			return $cmp unless ($@);
-		}
-	}
-	
-	if ($numericcmp) {
-		$l->trace('both numeric cmp');
-		return 0 if ($nodea->equal( $nodeb ));	# if the nodes are identical, return true (even if the lexical values don't appear to be numeric). i.e., "xyz"^^xsd:integer should equal itself, even though it's not a valid integer.
+		return DateTime->compare( $datea, $dateb );
+	} elsif ($numericcmp) {
+		warn 'both numeric cmp' if ($debug);
 		return $nodea->numeric_value <=> $nodeb->numeric_value;
-	}
-	
-	{
-		$l->trace('other cmp');
+	} else {
+		warn 'other cmp' if ($debug);
 		
 		if ($nodea->has_language and $nodeb->has_language) {
-			$l->trace('both have language');
+			warn "both have language" if ($debug);
 			my $lc	= lc($nodea->literal_value_language) cmp lc($nodeb->literal_value_language);
 			my $vc	= $nodea->literal_value cmp $nodeb->literal_value;
 			my $c;
@@ -105,13 +89,13 @@ sub _cmp {
 			} elsif ($lc == 0) {
 				$c	= $vc;
 			} else {
-				$l->debug("Attempt to compare literals with differing languages.");
+				warn "Attempt to compare literals with differing languages." if ($debug);
 				throw RDF::Query::Error::TypeError -text => "Attempt to compare literals with differing languages.";
 			}
-			$l->trace("-> $c");
+			warn "-> $c" if ($debug);
 			return $c;
 		} elsif (($nodea->has_datatype and $dta eq 'http://www.w3.org/2001/XMLSchema#string') or ($nodeb->has_datatype and $dtb eq 'http://www.w3.org/2001/XMLSchema#string')) {
-			$l->trace("one is xsd:string");
+			warn "one is xsd:string" if ($debug);
 			no warnings 'uninitialized';
 			my ($na, $nb)	= sort {
 								(blessed($b) and $b->isa('RDF::Query::Node::Literal'))
@@ -126,15 +110,13 @@ sub _cmp {
 				$c	= -1;
 			} elsif (not($nb->has_datatype) or $nb->literal_datatype eq 'http://www.w3.org/2001/XMLSchema#string') {
 				$c	= $nodea->literal_value cmp $nodeb->literal_value;
-			} elsif ($LAZY_COMPARISONS) {
-				return $nodea->as_string cmp $nodeb->as_string;
 			} else {
 				throw RDF::Query::Error::TypeError -text => "Attempt to compare typed-literal with xsd:string.";
 			}
-			$l->trace("-> $c");
+			warn "-> $c" if ($debug);
 			return $c;
 		} elsif ($nodea->has_datatype and $nodeb->has_datatype) {
-			$l->trace("both have datatype");
+			warn "both have datatype" if ($debug);
 			my $dc	= $nodea->literal_datatype cmp $nodeb->literal_datatype;
 			my $vc	= $nodea->literal_value cmp $nodeb->literal_value;
 			my $c;
@@ -147,31 +129,37 @@ sub _cmp {
 				} elsif ($dc == 0) {
 					$c	= $vc;
 				} else {
-					$l->debug("Attempt to compare literals with different datatypes.");
+					warn "Attempt to compare literals with different datatypes." if ($debug);
 					throw RDF::Query::Error::TypeError -text => "Attempt to compare literals with differing datatypes.";
 				}
-				$l->trace("-> $c");
+				warn "-> $c" if ($debug);
 				return $c;
 			}
 		} elsif ($nodea->has_language or $nodeb->has_language) {
-			$l->trace("one has language");
-			my $c	= ($nodea->has_language) ? 1 : -1;
-			$l->trace("-> $c");
-			return $c;
-		} elsif ($nodea->has_datatype or $nodeb->has_datatype) {
-			$l->trace("one has datatype");
+			warn "one has language" if ($debug);
 			if ($LAZY_COMPARISONS) {
-				my $c	= ($nodea->has_datatype) ? 1 : -1;
-				$l->trace("-> $c");
+				my $c	= refaddr($nodea) <=> refaddr($nodeb);	# not equal, but will make the sort stable
+				warn "-> $c" if ($debug);
 				return $c;
 			} else {
-				$l->debug("Attempt to compare typed-literal with plain-literal");
+				my $c	= refaddr($nodea) <=> refaddr($nodeb);	# not equal, but stable sorting
+				warn "-> $c" if ($debug);
+				return $c;
+			}
+		} elsif ($nodea->has_datatype or $nodeb->has_datatype) {
+			warn "one has datatype" if ($debug);
+			if ($LAZY_COMPARISONS) {
+				my $c	= refaddr($nodea) <=> refaddr($nodeb);	# not equal, but will make the sort stable
+				warn "-> $c" if ($debug);
+				return $c;
+			} else {
+				warn "Attempt to compare typed-literal with plain-literal" if ($debug);
 				throw RDF::Query::Error::TypeError -text => "Attempt to compare typed-literal with plain-literal";
 			}
 		} else {
-			$l->trace("something else");
+			warn "something else" if ($debug);
 			my $vcmp	= $nodea->literal_value cmp $nodeb->literal_value;
-			$l->trace("-> $vcmp");
+			warn "-> $vcmp" if ($debug);
 			return $vcmp;
 		}
 	}
@@ -212,35 +200,6 @@ sub as_sparql {
 	}
 }
 
-=item C<< as_hash >>
-
-Returns the query as a nested set of plain data structures (no objects).
-
-=cut
-
-sub as_hash {
-	my $self	= shift;
-	my $context	= shift;
-	my $hash	= {
-		type 		=> 'node',
-		literal		=> $self->literal_value,
-	};
-	$hash->{ language }	= $self->literal_value_language if ($self->has_language);
-	$hash->{ datatype }	= $self->literal_datatype if ($self->has_datatype);
-	return $hash;
-}
-
-=item C<< is_simple_literal >>
-
-Returns true if the literal is "simple" -- is a literal without datatype or language.
-
-=cut
-
-sub is_simple_literal {
-	my $self	= shift;
-	return not($self->has_language or $self->has_datatype);
-}
-
 =item C<< is_numeric_type >>
 
 Returns true if the literal is a known (xsd) numeric type.
@@ -269,8 +228,7 @@ sub numeric_value {
 	if ($self->is_numeric_type) {
 		my $value	= $self->literal_value;
 		if (looks_like_number($value)) {
-			my $v	= 0 + eval "$value";
-			return $v;
+			return 0 + $value;
 		} else {
 			throw RDF::Query::Error::TypeError -text => "Literal with numeric type does not appear to have numeric value.";
 		}
@@ -287,19 +245,6 @@ sub numeric_value {
 	}
 }
 
-=item C<< type_list >>
-
-Returns a two-item list suitable for use as the second and third arguments to
-RDF::Query::Node::Literal constructor. The two returned values correspond to
-literal language tag and literal datatype URI, respectively.
-
-=cut
-
-sub type_list {
-	my $self	= shift;
-	return ($self->literal_value_language, $self->literal_datatype);
-}
-
 sub DESTROY {
 	my $self	= shift;
 	my $addr	= refaddr($self);
