@@ -5,10 +5,6 @@
 
 RDF::Query::Parser::RDQL - An RDQL parser for RDF::Query
 
-=head1 VERSION
-
-This document describes RDF::Query::Parser::RDQL version 2.917_01.
-
 =cut
 
 package RDF::Query::Parser::RDQL;
@@ -26,11 +22,12 @@ use Scalar::Util qw(blessed);
 
 ######################################################################
 
-our ($VERSION, $lang, $languri);
+our ($VERSION, $debug, $lang, $languri);
 BEGIN {
 	$::RD_TRACE	= undef;
 	$::RD_HINT	= undef;
-	$VERSION	= '2.917_01';
+	$debug		= 1;
+	$VERSION	= '2.001';
 	$lang		= 'rdql';
 	$languri	= 'http://jena.hpl.hp.com/2003/07/query/RDQL';
 }
@@ -38,7 +35,7 @@ BEGIN {
 our($RDQL_GRAMMAR);
 BEGIN {
 	our $RDQL_GRAMMAR	= <<'END';
-	query:			'SELECT' variable(s) SourceClause(?) 'WHERE' triplepattern(s) constraints(?) OptOrderBy(?) prefixes(?)
+	query:			'SELECT' variable(s) SourceClause(?) 'WHERE' triplepattern(s) constraints(?) OptOrderBy(?) 'USING' namespaces
 																	{
 																		my $triples	= RDF::Query::Algebra::GroupGraphPattern->new( @{ $item[5] } );
 																		my $filter	= ($item[6][0] || []);
@@ -52,20 +49,19 @@ BEGIN {
 																			variables	=> $item[2],
 																			sources		=> $item[3][0],
 																			triples		=> [ $triples ],
-																			namespaces	=> (scalar(@{$item[8]}) ? $item[8][0] : {})
+																			namespaces	=> $item[9]
 																		};
 																		if (@{ $item[7] }) {
 																			$return->{options}{orderby}	= $item[9][0];
 																		}
 																	}
-	prefixes:					'USING' namespaces								{ $return = $item[2] }
 	OptOrderBy:					'ORDER BY' orderbyvariable(s)					{ $return = $item[2] }
 	orderbyvariable:			variable										{ $return = ['ASC', $item[1]] }
 					|			/ASC|DESC/i '[' variable ']'					{ $return = [uc($item[1]), $item[3]] }
 	SourceClause:				('SOURCE' | 'FROM') Source(s)					{ $return = $item[2] }
 	Source:						URI												{ $return = [$item[1]] }
 	variable:					'?' identifier									{ $return = RDF::Query::Parser->new_variable($item[2]) }
-	triplepattern:				'(' VarUri VarUri VarUriConst ')'				{ $return = RDF::Query::Parser::RDQL::Triple->new(@item[2,3,4]) }
+	triplepattern:				'(' VarUri VarUri VarUriConst ')'				{ $return = RDF::Query::Parser->new_triple(@item[2,3,4]) }
 	constraints:				'AND' Expression OptExpression(s?)				{
 																					if (scalar(@{ $item[3] })) {
 																						my ($op, $expr)	= @{ $item[3][0] };
@@ -198,8 +194,7 @@ BEGIN {
 	namespace:					identifier 'FOR' qURI							{ $return = {@item[1,3]} }
 	OptComma:					',' | ''
 	identifier:					/(([a-zA-Z0-9_.-])+)/							{ $return = $1 }
-	URI:						qURI											{ $return = RDF::Query::Parser->new_uri( $item[1] ) }
-							|	QName											{ $return = RDF::Query::Parser::RDQL::URI->new( $item[1] ) }
+	URI:						(qURI | QName)									{ $return = RDF::Query::Parser->new_uri( $item[1] ) }
 	qURI:						'<' /[A-Za-z0-9_.!~*'()%;\/?:@&=+,#\$-]+/ '>'	{ $return = $item[2] }
 	QName:						identifier ':' /([^ \t<>()]+)/					{ $return = [@item[1,3]] }
 	CONST:						Text											{ $return = RDF::Query::Parser->new_literal($item[1]) }
@@ -249,43 +244,12 @@ sub parse {
 	my $parsed	= $parser->query( $query );
 	
 	if ($parsed) {
-		my $pattern	= $parsed->{triples}[0];
-		if (blessed($pattern)) {
-			my $ns		= $parsed->{namespaces};
-			$pattern	= $self->_fixup_pattern( $pattern, $ns );
-			my $fixed	= $pattern->qualify_uris( $ns );
-			$parsed->{triples}[0]	= $fixed;
-		}
-		$pattern	= RDF::Query::Algebra::Project->new( $parsed->{triples}[0], $parsed->{variables} );
-		$parsed->{triples}[0]	= $pattern;
-		
-		
 		return $parsed;
 	} else {
 		return $self->fail( "Failed to parse: '$query'" );
 	}
 }
 
-sub _fixup_pattern {
-	my $self	= shift;
-	my $pattern	= shift;
-	my $ns		= shift;
-	
-	my @uris	= $pattern->subpatterns_of_type('RDF::Query::Parser::RDQL::URI');
-	foreach my $u (@uris) {
-		my $ns	= $ns->{ $u->[0] };
-		my $uri	= join('', $ns, $u->[1]);
-		@{ $u }	=  ( 'URI', $uri );
-		bless($u, 'RDF::Query::Node::Resource');	# evil
-	}
-	
-	my @triples	= $pattern->subpatterns_of_type('RDF::Query::Parser::RDQL::Triple');
-	foreach my $t (@triples) {
-		bless($t, 'RDF::Query::Algebra::Triple');	# evil
-	}
-	return $pattern;
-}
-
 sub AUTOLOAD {
 	my $self	= $_[0];
 	throw RDF::Query::Error::MethodInvocationError unless (blessed($self));
@@ -310,41 +274,6 @@ sub AUTOLOAD {
 }
 
 
-package RDF::Query::Parser::RDQL::URI;
-
-use strict;
-use warnings;
-use base qw(RDF::Query::Algebra);
-
-sub new {
-	my $class	= shift;
-	my $data	= shift;
-	my ($ns, $local)	= @{ $data };
-	return bless([$ns, $local], $class);
-}
-
-sub construct_args {
-	my $self	= shift;
-	return [ @$self ];
-}
-
-package RDF::Query::Parser::RDQL::Triple;
-
-use strict;
-use warnings;
-use base qw(RDF::Query::Algebra);
-
-sub new {
-	my $class	= shift;
-	my @nodes	= @_;
-	return bless([@nodes], $class);
-}
-
-sub construct_args {
-	my $self	= shift;
-	return @$self;
-}
-
 1;
 
 __END__
