@@ -7,12 +7,12 @@ RDF::Query::Parser::SPARQL - SPARQL Parser.
 
 =head1 VERSION
 
-This document describes RDF::Query::Parser::SPARQL version 2.917_01.
+This document describes RDF::Query::Parser::SPARQL version 1.000
 
 =head1 SYNOPSIS
 
  use RDF::Query::Parser::SPARQL;
- my $parser	= RDF::Query::Parser::SPARQL->new();
+ my $parser	= RDF::Query::Parse::SPARQL->new();
  my $iterator = $parser->parse( $query, $base_uri );
 
 =head1 DESCRIPTION
@@ -21,9 +21,6 @@ This document describes RDF::Query::Parser::SPARQL version 2.917_01.
 
 =head1 METHODS
 
-Beyond the methods documented below, this class inherits methods from the
-L<RDF::Query::Parser> class.
-
 =over 4
 
 =cut
@@ -34,6 +31,7 @@ use strict;
 use warnings;
 no warnings 'redefine';
 use base qw(RDF::Query::Parser);
+our $VERSION		= '2.001';
 
 use URI;
 use Data::Dumper;
@@ -42,43 +40,36 @@ use RDF::Query::Parser;
 use RDF::Query::Algebra;
 use RDF::Trine::Namespace qw(rdf);
 use Scalar::Util qw(blessed looks_like_number);
+use List::MoreUtils qw(uniq);
 
-######################################################################
-
-our ($VERSION);
-BEGIN {
-	$VERSION	= '2.917_01';
-}
-
-######################################################################
-
+our $debug		= 0;
 my $rdf			= RDF::Trine::Namespace->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#');
 my $xsd			= RDF::Trine::Namespace->new('http://www.w3.org/2001/XMLSchema#');
 
-our $r_ECHAR				= qr/\\([tbnrf\\"'])/o;
-our $r_STRING_LITERAL1		= qr/'(([^\x{27}\x{5C}\x{0A}\x{0D}])|${r_ECHAR})*'/o;
-our $r_STRING_LITERAL2		= qr/"(([^\x{22}\x{5C}\x{0A}\x{0D}])|${r_ECHAR})*"/o;
-our $r_STRING_LITERAL_LONG1	= qr/'''(('|'')?([^'\\]|${r_ECHAR}))*'''/o;
-our $r_STRING_LITERAL_LONG2	= qr/"""(("|"")?([^"\\]|${r_ECHAR}))*"""/o;
-our $r_LANGTAG				= qr/@[a-zA-Z]+(-[a-zA-Z0-9]+)*/o;
-our $r_IRI_REF				= qr/<([^<>"{}|^`\\\x{00}-\x{20}])*>/o;
-our $r_PN_CHARS_BASE		= qr/([A-Z]|[a-z]|[\x{00C0}-\x{00D6}]|[\x{00D8}-\x{00F6}]|[\x{00F8}-\x{02FF}]|[\x{0370}-\x{037D}]|[\x{037F}-\x{1FFF}]|[\x{200C}-\x{200D}]|[\x{2070}-\x{218F}]|[\x{2C00}-\x{2FEF}]|[\x{3001}-\x{D7FF}]|[\x{F900}-\x{FDCF}]|[\x{FDF0}-\x{FFFD}]|[\x{10000}-\x{EFFFF}])/o;
-our $r_PN_CHARS_U			= qr/(_|${r_PN_CHARS_BASE})/o;
-our $r_VARNAME				= qr/((${r_PN_CHARS_U}|[0-9])(${r_PN_CHARS_U}|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}])*)/o;
-our $r_VAR1					= qr/[?]${r_VARNAME}/o;
-our $r_VAR2					= qr/[\$]${r_VARNAME}/o;
-our $r_PN_CHARS				= qr/${r_PN_CHARS_U}|-|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}]/o;
-our $r_PN_PREFIX			= qr/(${r_PN_CHARS_BASE}((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/o;
-our $r_PN_LOCAL				= qr/((${r_PN_CHARS_U}|[0-9])((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/o;
-our $r_PNAME_NS				= qr/((${r_PN_PREFIX})?:)/o;
-our $r_PNAME_LN				= qr/(${r_PNAME_NS}${r_PN_LOCAL})/o;
-our $r_EXPONENT				= qr/[eE][-+]?\d+/o;
-our $r_DOUBLE				= qr/\d+[.]\d*${r_EXPONENT}|[.]\d+${r_EXPONENT}|\d+${r_EXPONENT}/o;
-our $r_DECIMAL				= qr/(\d+[.]\d*)|([.]\d+)/o;
-our $r_INTEGER				= qr/\d+/o;
-our $r_BLANK_NODE_LABEL		= qr/_:${r_PN_LOCAL}/o;
-our $r_ANON					= qr/\[[\t\r\n ]*\]/o;
-our $r_NIL					= qr/\([\n\r\t ]*\)/o;
+our $r_ECHAR				= qr/\\([tbnrf\\"'])/;
+our $r_STRING_LITERAL1		= qr/'(([^\x{27}\x{5C}\x{0A}\x{0D}])|${r_ECHAR})*'/;
+our $r_STRING_LITERAL2		= qr/"(([^\x{22}\x{5C}\x{0A}\x{0D}])|${r_ECHAR})*"/;
+our $r_STRING_LITERAL_LONG1	= qr/'''(('|'')?([^'\\]|${r_ECHAR}))*'''/;
+our $r_STRING_LITERAL_LONG2	= qr/"""(("|"")?([^"\\]|${r_ECHAR}))*"""/;
+our $r_LANGTAG				= qr/@[a-zA-Z]+(-[a-zA-Z0-9]+)*/;
+our $r_IRI_REF				= qr/<([^<>"{}|^`\\\x{00}-\x{20}])*>/;
+our $r_PN_CHARS_BASE		= qr/([A-Z]|[a-z]|[\x{00C0}-\x{00D6}]|[\x{00D8}-\x{00F6}]|[\x{00F8}-\x{02FF}]|[\x{0370}-\x{037D}]|[\x{037F}-\x{1FFF}]|[\x{200C}-\x{200D}]|[\x{2070}-\x{218F}]|[\x{2C00}-\x{2FEF}]|[\x{3001}-\x{D7FF}]|[\x{F900}-\x{FDCF}]|[\x{FDF0}-\x{FFFD}]|[\x{10000}-\x{EFFFF}])/;
+our $r_PN_CHARS_U			= qr/(_|${r_PN_CHARS_BASE})/;
+our $r_VARNAME				= qr/((${r_PN_CHARS_U}|[0-9])(${r_PN_CHARS_U}|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}])*)/;
+our $r_VAR1					= qr/[?]${r_VARNAME}/;
+our $r_VAR2					= qr/[\$]${r_VARNAME}/;
+our $r_PN_CHARS				= qr/${r_PN_CHARS_U}|-|[0-9]|\x{00B7}|[\x{0300}-\x{036F}]|[\x{203F}-\x{2040}]/;
+our $r_PN_PREFIX			= qr/(${r_PN_CHARS_BASE}((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/;
+our $r_PN_LOCAL				= qr/((${r_PN_CHARS_U}|[0-9])((${r_PN_CHARS}|[.])*${r_PN_CHARS})?)/;
+our $r_PNAME_NS				= qr/((${r_PN_PREFIX})?:)/;
+our $r_PNAME_LN				= qr/(${r_PNAME_NS}${r_PN_LOCAL})/;
+our $r_EXPONENT				= qr/[eE][-+]?\d+/;
+our $r_DOUBLE				= qr/\d+[.]\d*${r_EXPONENT}|[.]\d+${r_EXPONENT}|\d+${r_EXPONENT}/;
+our $r_DECIMAL				= qr/(\d+[.]\d*)|([.]\d+)/;
+our $r_INTEGER				= qr/\d+/;
+our $r_BLANK_NODE_LABEL		= qr/_:${r_PN_LOCAL}/;
+our $r_ANON					= qr/\[[\t\r\n ]*\]/;
+our $r_NIL					= qr/\([\n\r\t ]*\)/;
 
 =item C<< new >>
 
@@ -179,48 +170,6 @@ sub parse_pattern {
 	return $data->{triples}[0];
 }
 
-=item C<< parse_expr ( $pattern, $base_uri, \%namespaces ) >>
-
-Parses the C<< $pattern >>, using the given C<< $base_uri >> and returns a
-RDF::Query::Expression pattern.
-
-=cut
-
-sub parse_expr {
-	my $self	= shift;
-	my $input	= shift;
-	my $baseuri	= shift;
-	my $ns		= shift;
-	
-	$input		=~ s/\\u([0-9A-Fa-f]{4})/chr(hex($1))/ge;
-	$input		=~ s/\\U([0-9A-Fa-f]{8})/chr(hex($1))/ge;
-	
-	delete $self->{error};
-	local($self->{namespaces})				= $ns;
-	local($self->{blank_ids})				= 1;
-	local($self->{baseURI})					= $baseuri;
-	local($self->{tokens})					= $input;
-	local($self->{stack})					= [];
-	local($self->{filters})					= [];
-	local($self->{pattern_container_stack})	= [];
-	my $triples								= $self->_push_pattern_container();
-	$self->{build}							= { sources => [], triples => $triples };
-	if ($baseuri) {
-		$self->{build}{base}	= $baseuri;
-	}
-	
-	try {
-		$self->_Expression();
-	} catch RDF::Query::Error with {
-		my $e	= shift;
-		$self->{build}	= undef;
-		$self->{error}	= $e->text;
-	};
-	
-	my $data	= splice(@{ $self->{stack} });
-	return $data;
-}
-
 =item C<< error >>
 
 Returns the error encountered during the last parse.
@@ -290,8 +239,8 @@ sub _eat {
 # 	}
 	
 	if (blessed($thing) and $thing->isa('Regexp')) {
-		if ($self->{tokens} =~ /^($thing)/) {
-			my $match	= $1;
+		if ($self->{tokens} =~ /^$thing/) {
+			my $match	= $&;
 			substr($self->{tokens}, 0, length($match))	= '';
 			return $match;
 		}
@@ -326,10 +275,7 @@ sub _syntax_error {
 		}
 	}
 	
-	my $l		= Log::Log4perl->get_logger("rdf.query.parser.sparql");
-	if ($l->is_debug) {
-		$l->logcluck("Syntax error eating $thing with input <<$self->{tokens}>>");
-	}
+	Carp::cluck( "eating $thing with input <<$self->{tokens}>>" ) if ($debug);
 	throw RDF::Query::Error::ParseError -text => "Syntax error: Expected $expect";
 }
 
@@ -427,16 +373,13 @@ sub _Query {
 	} elsif ($self->_test(qr/ASK/i)) {
 		$self->_AskQuery();
 	} else {
-		my $l		= Log::Log4perl->get_logger("rdf.query");
-		if ($l->is_debug) {
-			$l->logcluck("Syntax error: Expected query type with input <<$self->{tokens}>>");
-		}
+		Carp::cluck( "with input <<$self->{tokens}>>" ) if ($debug);
 		throw RDF::Query::Error::ParseError -text => 'Syntax error: Expected query type';
 	}
 	
 	my $remaining	= $self->{tokens};
 	if ($remaining =~ m/\S/) {
-		throw RDF::Query::Error::ParseError -text => "Syntax error: Remaining input after query: $remaining";
+		throw RDF::Query::Error::ParseError -text => "Remaining input after query: $remaining";
 	}
 	
 # 	my %query	= (%p, %body);
@@ -513,20 +456,40 @@ sub _SelectQuery {
 
 	if ($star) {
 		my $triples	= $self->{build}{triples} || [];
-		my @vars	= RDF::Query::_uniq( map { $_->referenced_variables } @$triples );
+		my @vars	= uniq( map { $_->referenced_variables } @$triples );
 		$self->{build}{variables}	= [ map { $self->new_variable($_) } @vars ];
 	}
 
 	$self->__consume_ws_opt;
 	$self->_SolutionModifier();
 	
+	if ($self->{build}{options}{distinct}) {
+		delete $self->{build}{options}{distinct};
+		my $pattern	= pop(@{ $self->{build}{triples} });
+		my $sort	= RDF::Query::Algebra::Distinct->new( $pattern );
+		push(@{ $self->{build}{triples} }, $sort);
+	}
+	
 	if ($self->{build}{options}{orderby}) {
 		my $order	= delete $self->{build}{options}{orderby};
 		my $pattern	= pop(@{ $self->{build}{triples} });
 		my $sort	= RDF::Query::Algebra::Sort->new( $pattern, @$order );
 		push(@{ $self->{build}{triples} }, $sort);
 	}
-	$self->__solution_modifiers( $star );
+	
+	if (exists $self->{build}{options}{offset}) {
+		my $offset		= delete $self->{build}{options}{offset};
+		my $pattern		= pop(@{ $self->{build}{triples} });
+		my $offseted	= RDF::Query::Algebra::Offset->new( $pattern, $offset );
+		push(@{ $self->{build}{triples} }, $offseted);
+	}
+	
+	if (exists $self->{build}{options}{limit}) {
+		my $limit	= delete $self->{build}{options}{limit};
+		my $pattern	= pop(@{ $self->{build}{triples} });
+		my $limited	= RDF::Query::Algebra::Limit->new( $pattern, $limit );
+		push(@{ $self->{build}{triples} }, $limited);
+	}
 	
 	delete $self->{build}{options};
 	$self->{build}{method}		= 'SELECT';
@@ -574,13 +537,7 @@ sub _ConstructQuery {
 	$self->_DatasetClause();
 	$self->__consume_ws_opt;
 	$self->_WhereClause;
-	$self->__consume_ws_opt;
 	$self->_SolutionModifier();
-	
-	my $pattern		= $self->{build}{triples}[0];
-	my $triples		= delete $self->{build}{construct_triples};
-	my $construct	= RDF::Query::Algebra::Construct->new( $pattern, $triples );
-	$self->{build}{triples}[0]	= $construct;
 	$self->{build}{method}		= 'CONSTRUCT';
 }
 
@@ -609,7 +566,6 @@ sub _DescribeQuery {
 	$self->__consume_ws_opt;
 	if ($self->_WhereClause_test) {
 		$self->_WhereClause;
-		$self->__consume_ws_opt;
 	}
 	
 	$self->_SolutionModifier();
@@ -993,14 +949,12 @@ sub _GraphGraphPattern {
 	$self->__consume_ws;
 	$self->_VarOrIRIref;
 	my ($graph)	= splice(@{ $self->{stack} });
-	$self->__consume_ws_opt;
 	
-# 	if ($graph->isa('RDF::Trine::Node::Resource')) {
+	{
 		local($self->{named_graph})	= $graph;
+		$self->__consume_ws_opt;
 		$self->_GroupGraphPattern;
-# 	} else {
-# 		$self->_GroupGraphPattern;
-# 	}
+	}
 	
 	my $ggp	= $self->_remove_pattern;
 	my $pattern	= RDF::Query::Algebra::NamedGraph->new( $graph, $ggp );
@@ -1707,7 +1661,7 @@ sub _RDFLiteral {
 	if ($self->_test('@')) {
 		my $lang	= $self->_eat( $r_LANGTAG );
 		substr($lang,0,1)	= '';	# remove '@'
-		push(@args, lc($lang));
+		push(@args, $lang);
 	} elsif ($self->_test('^^')) {
 		$self->_eat('^^');
 		push(@args, undef);
@@ -1780,10 +1734,10 @@ sub _String {
 		$value		= substr($string, 1, length($string) - 2);
 	}
 #	$value	=~ s/(${r_ECHAR})/"$1"/ge;
-	$value	=~ s/\\t/\t/g;
-	$value	=~ s/\\b/\x08/g;
+	$value	=~ s/\\t/\n/g;
+	$value	=~ s/\\b/\n/g;
 	$value	=~ s/\\n/\n/g;
-	$value	=~ s/\\r/\r/g;
+	$value	=~ s/\\r/\n/g;
 	$value	=~ s/\\"/"/g;
 	$value	=~ s/\\'/'/g;
 	$value	=~ s/\\\\/\\/g;	# backslash must come last, so it doesn't accidentally create a new escape
@@ -1860,41 +1814,6 @@ sub _NIL {
 	$self->_add_stack( $nil );
 }
 
-sub __solution_modifiers {
-	my $self	= shift;
-	my $star	= shift;
-	
-	my $vars	= $self->{build}{variables};
-	my $pattern	= pop(@{ $self->{build}{triples} });
-	my $proj	= RDF::Query::Algebra::Project->new( $pattern, $vars );
-	push(@{ $self->{build}{triples} }, $proj);
-	
-	if ($self->{build}{options}{distinct}) {
-		delete $self->{build}{options}{distinct};
-		my $pattern	= pop(@{ $self->{build}{triples} });
-		my $sort	= RDF::Query::Algebra::Distinct->new( $pattern );
-		push(@{ $self->{build}{triples} }, $sort);
-	}
-	
-	if (exists $self->{build}{options}{offset}) {
-		my $offset		= delete $self->{build}{options}{offset};
-		my $pattern		= pop(@{ $self->{build}{triples} });
-		my $offseted	= RDF::Query::Algebra::Offset->new( $pattern, $offset );
-		push(@{ $self->{build}{triples} }, $offseted);
-	}
-	
-	if (exists $self->{build}{options}{limit}) {
-		my $limit	= delete $self->{build}{options}{limit};
-		my $pattern	= pop(@{ $self->{build}{triples} });
-		my $limited	= RDF::Query::Algebra::Limit->new( $pattern, $limit );
-		push(@{ $self->{build}{triples} }, $limited);
-	}
-}
-
 1;
 
 __END__
-
-=back
-
-=cut
